@@ -3,7 +3,7 @@ order the pieces by increasing area
 """
 from vedo import *
 
-em = Volume(datadir+"embryo.tif").isosurface(80)
+em = Volume(dataurl+"embryo.tif").isosurface(80)
 
 # return the list of the largest 10 connected meshes:
 splitem = em.splitByConnectivity(maxdepth=40)[0:9]
