@@ -4,7 +4,7 @@ moves as the arrow indicates. """
 from vedo import *
 
 
-mesh = load(datadir+"man.vtk").color('w').lineWidth(0.1)
+mesh = load(dataurl+"man.vtk").color('w').lineWidth(0.1)
 
 # a heavily decimated copy
 meshdec = mesh.clone().triangulate().decimate(N=200)
@@ -19,7 +19,7 @@ for pt in meshdec.points():
         targets.append(pt)   #
 
 warp = mesh.clone().thinPlateSpline(sources, targets)
-warp.c("blue").alpha(0.4).lineWidth(0)
+warp.c("blue",0.3).lineWidth(0)
 
 apts = Points(sources).c("red")
 
