@@ -2,8 +2,8 @@
 the red line to the yellow surface"""
 from vedo import *
 
-limb = load(datadir + "270.vtk").c("gold").flag()
-rim  = load(datadir + "270_rim.vtk").c("red").lw(4)
+limb = load(dataurl + "270.vtk").c("gold").flag()
+rim  = load(dataurl + "270_rim.vtk").c("red").lw(4)
 
 # Make a clone copy of rim and align it to limb
 # rigid=True doesn't allow scaling
