@@ -4,7 +4,7 @@ from vedo import *
 
 vp = Plotter()
 
-mesh = vp.load(datadir+"magnolia.vtk").c("v").flat()
+mesh = vp.load(dataurl+"magnolia.vtk").c("v").flat()
 
 # add a button to the current renderer (e.i. nr1)
 def buttonfunc():
@@ -15,7 +15,7 @@ def buttonfunc():
 bu = vp.addButton(
     buttonfunc,
     pos=(0.7, 0.05),  # x,y fraction from bottom left corner
-    states=["press to hide", "press to show"],
+    states=["click to hide", "click to show"],
     c=["w", "w"],
     bc=["dg", "dv"],  # colors of states
     font="courier",   # arial, courier, times
