@@ -3,7 +3,7 @@ Example usage of cmap() to assign a color to each mesh vertex
 by looking it up in matplotlib database of colormaps
 """
 print(__doc__)
-from vedo import Plotter, datadir
+from vedo import Plotter, dataurl
 
 # these are the some matplotlib color maps
 mapkeys = [
@@ -24,7 +24,7 @@ mapkeys = [
 vp = Plotter(N=len(mapkeys))
 vp.legendSize = 0.4
 
-mug = vp.load(datadir+"mug.ply")
+mug = vp.load(dataurl+"mug.ply")
 
 scalars = mug.points()[:, 1]  # let y-coord be the scalar
 
