@@ -2,7 +2,7 @@ from vedo import *
 
 styles = ['default', 'metallic', 'plastic', 'shiny', 'glossy', 'ambient', 'off']
 
-a = load(datadir+"beethoven.ply").c('gold').subdivide()
+a = load(dataurl+"beethoven.ply").c('gold').subdivide()
 
 for i,s in enumerate(styles):
     show(a.clone(deep=False).lighting(s), Text2D(s),
