@@ -12,8 +12,8 @@ rads = [abs(pts[i][1]) / 10 for i in cols]  # radius=0 for y=0
 
 # all have same radius but different colors:
 s0 = Spheres(pts, c=cols, r=0.1, res=5)  # res= theta-phi resolution
-show(s0, __doc__+str(N), at=0, N=2, axes=2, viewup=(-0.7, 0.7, 0))
+show(s0, __doc__+str(N), at=0, N=2, axes=1, viewup=(-0.7, 0.7, 0))
 
 # all have same color but different radius along y:
 s1 = Spheres(pts, r=rads, c="lb", res=8)
-show(s1, at=1, zoom=1.5, interactive=1)
+show(s1, at=1, axes=2, interactive=True)
