@@ -1,9 +1,9 @@
 """Create a set of transparencies
 which can be passed to method cmap()
 """
-from vedo import load, show, datadir
+from vedo import load, show, dataurl
 
-mesh = load(datadir+"beethoven.ply")
+mesh = load(dataurl+"beethoven.ply")
 
 # pick y coordinates of vertices and use them as scalars
 scals = mesh.points()[:, 1]
