@@ -1,8 +1,9 @@
 """Form a surface by joining two lines"""
 from vedo import *
+import numpy as np
 
-l1 = [[sin(x), cos(x), x/3] for x in arange(0,9, 0.1)]
-l2 = [[sin(x)+0.2, cos(x) + x/15, x/3] for x in arange(0,9, 0.1)]
+l1 = [[sin(x), cos(x), x/3] for x in np.arange(0,9, 0.1)]
+l2 = [[sin(x)+0.2, cos(x) + x/15, x/3] for x in np.arange(0,9, 0.1)]
 
 t1 = Tube(l1, c="g", r=0.02)
 t2 = Tube(l2, c="b", r=0.02)
