@@ -2,7 +2,7 @@
 to make the inside visible"""
 from vedo import *
 
-pot = load(datadir+"teapot.vtk").shrink(0.75)
+pot = load(dataurl+"teapot.vtk").shrink(0.75)
 
 s = Sphere(r=0.2).pos(0, 0, -0.5)
 
