@@ -1,7 +1,7 @@
 from vedo import *
 
-m1 = load(datadir+'bunny.obj').c('g').normalize().rotateX(+90)
-m2 = load(datadir+'teddy.vtk').c('v').normalize().rotateZ(-90).pos(3,0,0)
+m1 = load(dataurl+'bunny.obj').c('g').normalize().rotateX(+90)
+m2 = load(dataurl+'teddy.vtk').c('v').normalize().rotateZ(-90).pos(3,0,0)
 
 show(m1, m2, axes=1)
 
