@@ -6,7 +6,7 @@ ventilation and a burning cigarette.
 # https://github.com/Kitware/VTK/blob/master/Examples/
 #  VisualizationAlgorithms/Python/officeTube.py
 from vedo import *
-from office_furniture import furniture
+from off_furniture import furniture
 
 # We read a data file the is a CFD analysis of airflow in an office
 # (with ventilation and a burning cigarette).
