@@ -6,9 +6,9 @@ from vedo import *
 ######################## vtk
 # Read the data and specify which scalars and vectors to read.
 pl3d = vtk.vtkMultiBlockPLOT3DReader()
-fpath = download(datadir+"combxyz.bin")
+fpath = download(dataurl+"combxyz.bin")
 pl3d.SetXYZFileName(fpath)
-fpath = download(datadir+"combq.bin")
+fpath = download(dataurl+"combq.bin")
 pl3d.SetQFileName(fpath)
 pl3d.SetScalarFunctionNumber(100)
 pl3d.SetVectorFunctionNumber(202)
