@@ -63,14 +63,14 @@ def Slicer(volume,
                  screensize=screensize,
                  title=title,
                  interactive=False,
-                 verbose=verbose)
+                )
 
     ################################
     box = volume.box().wireframe().alpha(0)
 
     vp.show(box, viewup="z", axes=axes)
     if showIcon:
-        vp.showInset(volume, pos=(.85,.85), size=0.15, c='w', draggable=draggable)
+        vp.addInset(volume, pos=(.85,.85), size=0.15, c='w', draggable=draggable)
 
     # inits
     la, ld = 0.7, 0.3 #ambient, diffuse
@@ -501,7 +501,7 @@ def IsosurfaceBrowser(volume, c=None, alpha=1, lego=False, cmap='hot', pos=None)
 
 
 ##############################################################################
-def Browser(meshes, sliderpos=((0.55, 0.07),(0.96, 0.07)), c=None):
+def Browser(meshes, sliderpos=((0.55, 0.07),(0.96, 0.07)), c=None, prefix=""):
     """
     Generate a ``Plotter`` window to browse a list of objects using a slider.
     Returns the ``Plotter`` object.
@@ -527,11 +527,7 @@ def Browser(meshes, sliderpos=((0.55, 0.07),(0.96, 0.07)), c=None):
             tx = tx.split("\\")[-1] # windows os
         elif ak.name:
             tx = ak.name
-        widget.GetRepresentation().SetTitleText(tx)
-        #printc("Browser Mode", c="y", invert=1, end="")
-        #if tx:
-        #    printc(": showing #", k, tx, " "*abs(40-len(tx))+"\r",
-        #           c="y", bold=0, end="")
+        widget.GetRepresentation().SetTitleText(prefix+tx)
 
     printc("Browser Mode", c="y", invert=1, end="")
     printc(" loaded", len(meshes), "objects", c="y", bold=False)
@@ -570,7 +566,6 @@ class Animation(Plotter):
     def __init__(self, totalDuration=None, timeResolution=0.02, showProgressBar=True,
                  videoFileName='animation.mp4', videoFPS=12):
         Plotter.__init__(self)
-        self.verbose = False
         self.resetcam = True
 
         self.events = []
@@ -901,7 +896,7 @@ class Animation(Plotter):
                 d = linInterpolate(tt, [t,t+duration], [dmin, diag*1.01])
                 if d>0:
                     ids = acts[0].closestPoint(corners[corner],
-                                               radius=d, returnIds=True)
+                                               radius=d, returnPointId=True)
                     if len(ids) <= acts[0].N():
                         self.events.append((tt, self.meshErode, acts, ids))
         else:
