@@ -1,4 +1,3 @@
-from __future__ import division, print_function
 import numpy as np
 import vtk
 import vedo
@@ -30,6 +29,8 @@ class Base3DProp(object):
     def __init__(self):
         self.filename = ""
         self.name = ""
+        self.fileSize = ''
+        self.created = ''
         self.trail = None
         self.trailPoints = []
         self.trailSegmentSize = 0
@@ -45,10 +46,9 @@ class Base3DProp(object):
         self.base = np.array([0,0,0])
         self.info = dict()
         self._time = 0
-        self._legend = None
         self.renderedAt = set()
         self.transform = None
-        self._set2actcam = False
+        self._set2actcam = False # used by mesh.followCamera()
 
     def address(self):
         """
@@ -60,13 +60,21 @@ class Base3DProp(object):
         return int(self.inputdata().GetAddressAsString('')[5:], 16)
 
     def pickable(self, value=None):
-        """Set/get pickable property of mesh."""
+        """Set/get pickable property of an object."""
         if value is None:
             return self.GetPickable()
         else:
             self.SetPickable(value)
             return self
 
+    def draggable(self, value=None): # NOT FUNCTIONAL?
+        """Set/get draggable property of an object."""
+        if value is None:
+            return self.GetDragable()
+        else:
+            self.SetDragable(value)
+            return self
+
     def time(self, t=None):
         """Set/get object's absolute time."""
         if t is None:
@@ -90,13 +98,17 @@ class Base3DProp(object):
 
     def pos(self, x=None, y=None, z=None):
         """Set/Get object position."""
-        if x is None:
+        if x is None: # get functionality
             return np.array(self.GetPosition())
-        if z is None:  # assume p_x is of the form (x,y,z)
-            if y is not None: # assume x and y are given so z=0
-                z=0
-            else: # assume p_x is of the form (x,y,z)
+
+        if z is None and y is None: # assume x is of the form (x,y,z)
+            if len(x)==3:
                 x, y, z = x
+            else:
+                x, y = x
+                z=0
+        elif z is None:             # assume x,y is of the form x, y
+            z=0
         self.SetPosition(x, y, z)
 
         if self.trail:
@@ -105,19 +117,28 @@ class Base3DProp(object):
             self._updateShadow()
         return self  # return itself to concatenate methods
 
-    def addPos(self, dp_x=None, dy=None, dz=None):
-        """Add vector to current object position."""
+    def addPos(self, dx=0, dy=0, dz=0):
+        """Add vector to current object position. Same as `shift()`."""
         p = np.array(self.GetPosition())
-        if dz is None:  # assume dp_x is of the form (x,y,z)
-            self.SetPosition(p + dp_x)
+
+        if utils.isSequence(dx):
+            if len(dx) == 2:
+                self.SetPosition(p + [dx[0], dx[1], 0])
+            else:
+                self.SetPosition(p + dx)
         else:
-            self.SetPosition(p + [dp_x, dy, dz])
+            self.SetPosition(p + [dx,dy,dz])
+
         if self.trail:
             self.updateTrail()
         if self.shadow:
             self._updateShadow()
         return self
 
+    def shift(self, dx=0, dy=0, dz=0):
+        """Add vector to current object position. Same as `addPos()`."""
+        return self.addPos(dx, dy, dz)
+
     def x(self, position=None):
         """Set/Get object position along x axis."""
         p = self.GetPosition()
@@ -266,6 +287,19 @@ class Base3DProp(object):
         :param rotation: If != 0 rotate object around newaxis.
         :param rad: set to True if angle is in radians.
 
+        :Example:
+
+            .. code-block:: python
+
+                from vedo import *
+                objs = []
+                for i in range(-5, 5):
+                    p = [i/3, i/2, i]
+                    v = vector(i/10, i/20, 1)
+                    c = Circle(r=i/5+1.2).pos(p).orientation(v).lw(3)
+                    objs += [c, Arrow(p,p+v)]
+                show(objs, axes=1)
+
         |gyroscope2| |gyroscope2.py|_
         """
         if rad:
@@ -313,18 +347,41 @@ class Base3DProp(object):
         return self
 
 
-    def getTransform(self):
+    def getTransform(self, invert=False):
         """
-        Check if ``info.transform`` exists and returns a ``vtkTransform``.
+        Check if ``object.transform`` exists and returns a ``vtkTransform``.
         Otherwise return current user transformation (where the object is currently placed).
+
+        :param bool invert: return the inverse of the current transformation
+
+        :Example:
+
+            .. code-block:: python
+
+                from vedo import *
+
+                c1 = Cube()
+                c2 = c1.clone().c('violet').alpha(0.5) # copy of c1
+                v = vector(0.2,1,0)
+                p = vector(1,0,0)  # axis passes through this point
+                c2.rotate(90, axis=v, point=p)
+
+                # get the inverse of the current transformation
+                T = c2.getTransform(invert=True)
+                c2.applyTransform(T)  # put back c2 in place
+
+                l = Line(p-v, p+v).lw(3).c('red')
+                show(c1.wireframe().lw(3), l, c2, axes=1)
         """
         if self.transform:
-            return self.transform
+            tr = self.transform
         else:
             T = self.GetMatrix()
             tr = vtk.vtkTransform()
             tr.SetMatrix(T)
-            return tr
+        if invert:
+            tr = tr.GetInverse()
+        return tr
 
     def applyTransform(self, T):
         """
@@ -340,6 +397,61 @@ class Base3DProp(object):
             self.SetUserMatrix(vm)
         else:
             self.SetUserTransform(T)
+        self.transform = T
+        return self
+
+    def alignToBoundingBox(self, msh, rigid=False):
+        """
+        Align the current object's bounding box to the bounding box
+        of the input object.
+
+        :param bool rigid: do not allow scaling if set to True
+
+        :Example:
+
+            .. code-block:: python
+
+                from vedo import *
+                eli = Ellipsoid().alpha(0.4)
+                cube= Cube().pos(3,2,1).rotateX(10).rotateZ(10).alpha(0.4)
+                eli.alignToBoundingBox(cube, rigid=False)
+                axes1 = Axes(eli, c='db')
+                axes2 = Axes(cube, c='dg')
+                show(eli, cube, axes1, axes2)
+        """
+        lmt = vtk.vtkLandmarkTransform()
+        ss = vtk.vtkPoints()
+        xss0,xss1,yss0,yss1,zss0,zss1 = self.bounds()
+        for p in [[xss0, yss0, zss0],
+                  [xss1, yss0, zss0],
+                  [xss1, yss1, zss0],
+                  [xss0, yss1, zss0],
+                  [xss0, yss0, zss1],
+                  [xss1, yss0, zss1],
+                  [xss1, yss1, zss1],
+                  [xss0, yss1, zss1],
+                 ]:
+            ss.InsertNextPoint(p)
+        st = vtk.vtkPoints()
+        xst0,xst1,yst0,yst1,zst0,zst1 = msh.bounds()
+        for p in [[xst0, yst0, zst0],
+                  [xst1, yst0, zst0],
+                  [xst1, yst1, zst0],
+                  [xst0, yst1, zst0],
+                  [xst0, yst0, zst1],
+                  [xst1, yst0, zst1],
+                  [xst1, yst1, zst1],
+                  [xst0, yst1, zst1],
+                 ]:
+            st.InsertNextPoint(p)
+
+        lmt.SetSourceLandmarks(ss)
+        lmt.SetTargetLandmarks(st)
+        if rigid:
+            lmt.SetModeToRigidBody()
+        lmt.Update()
+        self.applyTransform(lmt)
+        self.transform = lmt
         return self
 
 
@@ -353,7 +465,7 @@ class Base3DProp(object):
         self.VisibilityOff()
         return self
 
-    def box(self, scale=1, pad=0):
+    def box(self, scale=1, pad=0, fill=False):
         """Return the bounding box as a new ``Mesh``.
 
         :param float scale: box size can be scaled by a factor
@@ -362,21 +474,23 @@ class Base3DProp(object):
         .. hint:: |latex.py|_
         """
         b = self.GetBounds()
-        from vedo.shapes import Box
         if not utils.isSequence(pad):
             pad=[pad,pad,pad]
-        pos = (b[0]+b[1])/2, (b[3]+b[2])/2, (b[5]+b[4])/2
         length, width, height = b[1]-b[0], b[3]-b[2], b[5]-b[4]
-        bx = Box(pos,
-                 length*scale+pad[0], width*scale+pad[1], height*scale+pad[2],
-                 c='gray')
+        tol = (length+width+height)/30000 # useful for boxing 2D text
+        pos = [(b[0]+b[1])/2, (b[3]+b[2])/2, (b[5]+b[4])/2 -tol]
+        bx = vedo.shapes.Box(pos,
+                             length*scale+pad[0],
+                             width*scale+pad[1],
+                             height*scale+pad[2],
+                             c='gray')
         if hasattr(self, 'GetProperty'): # could be Assembly
             if isinstance(self.GetProperty(), vtk.vtkProperty): # could be volume
                 pr = vtk.vtkProperty()
                 pr.DeepCopy(self.GetProperty())
                 bx.SetProperty(pr)
         bx.flat().lighting('off')
-        bx.wireframe()
+        bx.wireframe(not fill)
         return bx
 
     def useBounds(self, ub=True):
@@ -390,19 +504,24 @@ class Base3DProp(object):
         Returns a list in format [xmin,xmax, ymin,ymax, zmin,zmax]."""
         return self.GetBounds()
 
-    def xbounds(self):
-        """Get the bounds [xmin,xmax]."""
+    def xbounds(self, i=None):
+        """Get the bounds [xmin,xmax]. Can specify upper or lower with i (0,1)."""
         b = self.GetBounds()
+        if i is not None: return b[i]
         return (b[0], b[1])
 
-    def ybounds(self):
-        """Get the bounds [ymin,ymax]."""
+    def ybounds(self, i=None):
+        """Get the bounds [ymin,ymax]. Can specify upper or lower with i (0,1)."""
         b = self.GetBounds()
+        if i == 0: return b[2]
+        elif i == 1: return b[3]
         return (b[2], b[3])
 
-    def zbounds(self):
-        """Get the bounds [zmin,zmax]."""
+    def zbounds(self, i=None):
+        """Get the bounds [zmin,zmax]. Can specify upper or lower with i (0,1)."""
         b = self.GetBounds()
+        if i == 0: return b[4]
+        elif i == 1: return b[5]
         return (b[4], b[5])
 
     def diagonalSize(self):
@@ -434,56 +553,9 @@ class Base3DProp(object):
         return self
 
     def buildAxes(self, **kargs):
-        """Draw axes for the input object or for a specified range.
+        """Generate axes for the input object or for a specified range.
         Returns an ``Assembly`` object.
 
-        - `xtitle`,                ['x'], x-axis title text
-        - `xrange`,               [None], x-axis range in format (xmin, ymin), default is automatic.
-        - `numberOfDivisions`,    [None], approximate number of divisions on the longest axis
-        - `axesLineWidth`,           [1], width of the axes lines
-        - `gridLineWidth`,           [1], width of the grid lines
-        - `reorientShortTitle`,   [True], titles shorter than 2 letter are placed horizontally
-        - `titleDepth`,              [0], extrusion fractional depth of title text
-        - `xyGrid`,               [True], show a gridded wall on plane xy
-        - `yzGrid`,               [True], show a gridded wall on plane yz
-        - `zxGrid`,               [True], show a gridded wall on plane zx
-        - `zxGrid2`,             [False], show zx plane on opposite side of the bounding box
-        - `xyGridTransparent`    [False], make grid plane completely transparent
-        - `xyGrid2Transparent`   [False], make grid plane completely transparent on opposite side box
-        - `xyPlaneColor`,       ['gray'], color of the plane
-        - `xyGridColor`,        ['gray'], grid line color
-        - `xyAlpha`,              [0.15], grid plane opacity
-        - `xyFrameLine`,          [None], add a frame for the plane
-        - `showTicks`,            [True], show major ticks
-        - `digits`,               [None], use this number of significant digits in scientific notation
-        - `titleFont`,              [''], font for axes titles
-        - `labelFont`,              [''], font for numeric labels
-        - `textScale`,             [1.0], global scaling factor for text elements (titles, labels)
-        - `xTitlePosition`,       [0.32], title fractional positions along axis
-        - `xTitleOffset`,         [0.05], title fractional offset distance from axis line
-        - `xTitleJustify`, ["top-right"], title justification
-        - `xTitleRotation`,          [0], add a rotation of the axis title
-        - `xTitleBox`,           [False], add a box around title text
-        - `xLineColor`,      [automatic], color of the x-axis
-        - `xTitleColor`,     [automatic], color of the axis title
-        - `xTitleBackfaceColor`,  [None],  color of axis title on its backface
-        - `xTitleSize`,          [0.025], size of the axis title
-        - 'xTitleItalic',            [0], a bool or float to make the font italic
-        - `xHighlightZero`,       [True], draw a line highlighting zero position if in range
-        - `xHighlightZeroColor`, [autom], color of the line highlighting the zero position
-        - `xTickLength`,         [0.005], radius of the major ticks
-        - `xTickThickness`,     [0.0025], thickness of the major ticks along their axis
-        - `xMinorTicks`,             [1], number of minor ticks between two major ticks
-        - `xValuesAndLabels`          [], assign custom tick positions and labels [(pos1, label1), ...]
-        - `xLabelColor`,     [automatic], color of numeric labels and ticks
-        - `xLabelPrecision`,         [2], nr. of significative digits to be shown
-        - `xLabelSize`,          [0.015], size of the numeric labels along axis
-        - 'xLabelRotation',          [0], rotate clockwise [1] or anticlockwise [-1] by 90 degrees
-        - 'xFlipText',           [False], flip axis title and numeric labels orientation
-        - `xLabelOffset`,        [0.025], offset of numeric labels
-        - `tipSize`,              [0.01], size of the arrow tip
-        - `limitRatio`,           [0.04], below this ratio don't plot small axis
-
         :Example:
 
             .. code-block:: python
@@ -493,12 +565,11 @@ class Base3DProp(object):
                 bax = b.buildAxes(c='k')  # returns Assembly object
                 show(b, bax)
 
-        |customAxes| |customAxes.py|_
+        |customAxes1| |customAxes1.py|_ |customAxes2.py|_ |customAxes3.py|_
 
         |customIndividualAxes| |customIndividualAxes.py|_
         """
-        from vedo.addons import Axes
-        a = Axes(self, **kargs)
+        a = vedo.addons.Axes(self, **kargs)
         self.axes = a
         return a
 
@@ -511,7 +582,7 @@ class Base3DProp(object):
         This is meant as a shortcut. If more than one object needs to be visualised
         please use the syntax `show(mesh1, mesh2, volume, ..., options)`.
 
-        :param bool newPlotter: if set to `True`, a call to ``show`` will instantiate
+        :param bool new: if set to `True`, a call to ``show`` will instantiate
             a new ``Plotter`` object (a new window) instead of reusing the first created.
             See e.g.: |readVolumeAsIsoSurface.py|_
 
@@ -527,8 +598,7 @@ class Base3DProp(object):
                 c = Cube()
                 c.show(at=0, interactive=True)
         """
-        from vedo.plotter import show
-        return show(self, **options)
+        return vedo.plotter.show(self, **options)
 
 
 ########################################################################################
@@ -592,6 +662,18 @@ class BaseActor(Base3DProp):
         vcen.Update()
         return vtk_to_numpy(vcen.GetOutput().GetPoints().GetData())
 
+
+    def deleteCells(self, ids):
+        """Remove cells from the mesh object by ID. Points (vertices) are not affected."""
+        data = self.inputdata()
+        for cid in ids:
+            data.DeleteCell(cid)
+        data.RemoveDeletedCells()
+        data.Modified()
+        self._mapper.Modified()
+        return self
+
+
     def findCellsWithin(self, xbounds=(), ybounds=(), zbounds=(), c=None):
         """
         Find cells that are within specified bounds.
@@ -659,10 +741,22 @@ class BaseActor(Base3DProp):
         pr = self.GetProperty()
 
         if style:
+
+            if isinstance(pr, vtk.vtkVolumeProperty):
+                self.shade(True)
+                if style=='off':
+                    self.shade(False)
+                elif style=='ambient':
+                    style='default'
+                    self.shade(False)
+            else:
+                if style!='off':
+                    pr.LightingOn()
+
             if style=='off':
                 pr.SetInterpolationToFlat()
                 pr.LightingOff()
-                return self
+                return self ##############
 
             if hasattr(pr, "GetColor"):  # could be Volume
                 c = pr.GetColor()
@@ -671,7 +765,7 @@ class BaseActor(Base3DProp):
             mpr = self._mapper
             if hasattr(mpr, 'GetScalarVisibility') and mpr.GetScalarVisibility():
                 c = (1,1,0.99)
-            if style=='metallic': pars = [0.1, 0.3, 1.0, 10, c]
+            if   style=='metallic': pars = [0.1, 0.3, 1.0, 10, c]
             elif style=='plastic' : pars = [0.3, 0.4, 0.3,  5, c]
             elif style=='shiny'   : pars = [0.2, 0.6, 0.8, 50, c]
             elif style=='glossy'  : pars = [0.1, 0.7, 0.9, 90, (1,1,0.99)]
@@ -694,6 +788,7 @@ class BaseActor(Base3DProp):
         if specularColor is not None: pr.SetSpecularColor(colors.getColor(specularColor))
         return self
 
+
     def printHistogram(self, bins=10, height=10, logscale=False, minbin=0,
                        horizontal=False, char=u"\U00002589",
                        c=None, bold=True, title='Histogram'):
@@ -729,12 +824,12 @@ class BaseActor(Base3DProp):
         return self
 
 
-    def c(self, color=False):
+    def c(self, color=False, alpha=None):
         """
         Shortcut for `color()`.
         If None is passed as input, will use colors from current active scalars.
         """
-        return self.color(color)
+        return self.color(color, alpha)
 
 
     def getArrayNames(self):
@@ -915,6 +1010,10 @@ class BaseActor(Base3DProp):
         if hasattr(self._mapper, 'SetArrayName'):
             self._mapper.SetArrayName(name)
         self._mapper.SetScalarModeToUsePointData()
+
+        if name == "Normals":
+            data.GetPointData().SetActiveNormals(name)
+
         return self
 
     def addCellArray(self, input_array, name):
@@ -935,6 +1034,7 @@ class BaseActor(Base3DProp):
                 self._mapper.SetArrayName(name)
             self._mapper.SetScalarModeToUseCellData()
             return self
+            ###########
 
         if len(input_array) != data.GetNumberOfCells():
             colors.printc('Error in addCellArray(): Number of inputs != nr. of Cells',
@@ -968,6 +1068,10 @@ class BaseActor(Base3DProp):
         if hasattr(self._mapper, 'SetArrayName'):
             self._mapper.SetArrayName(name)
         self._mapper.SetScalarModeToUseCellData()
+
+        if name == "Normals":
+            data.GetCellData().SetActiveNormals(name)
+
         return self
 
 
@@ -1112,8 +1216,8 @@ class BaseActor(Base3DProp):
 
 
     def addScalarBar(self,
-                     pos=(0.8,0.05),
                      title="",
+                     pos=(0.8,0.05),
                      titleYOffset=15,
                      titleFontSize=12,
                      size=(None,None),
@@ -1128,40 +1232,40 @@ class BaseActor(Base3DProp):
         .. hint:: |mesh_coloring| |mesh_coloring.py|_ |scalarbars.py|_
         """
         self.scalarbar = vedo.addons.addScalarBar(self,
-                                                 pos,
-                                                 title,
-                                                 titleYOffset,
-                                                 titleFontSize,
-                                                 size,
-                                                 nlabels,
-                                                 c,
-                                                 horizontal,
-                                                 useAlpha,
+                                                  title,
+                                                  pos,
+                                                  titleYOffset,
+                                                  titleFontSize,
+                                                  size,
+                                                  nlabels,
+                                                  c,
+                                                  horizontal,
+                                                  useAlpha,
                                                  )
         return self
 
 
-    def addScalarBar3D(self,
-        pos=None,
-        sx=None,
-        sy=None,
-        title='',
-        titleFont="",
-        titleXOffset = -1.5,
-        titleYOffset = 0.0,
-        titleSize =  1.5,
-        titleRotation = 0.0,
-        nlabels=9,
-        labelFont="",
-        labelOffset = 0.375,
-        italic=0,
-        c=None,
-        useAlpha=True,
-        drawBox=True,
-        aboveText=None,
-        belowText=None,
-        nanText='NaN',
-    ):
+    def addScalarBar3D( self,
+                        title='',
+                        pos=None,
+                        sx=None,
+                        sy=None,
+                        titleFont="",
+                        titleXOffset = -1.5,
+                        titleYOffset = 0.0,
+                        titleSize =  1.5,
+                        titleRotation = 0.0,
+                        nlabels=9,
+                        labelFont="",
+                        labelOffset = 0.375,
+                        italic=0,
+                        c=None,
+                        useAlpha=True,
+                        drawBox=True,
+                        aboveText=None,
+                        belowText=None,
+                        nanText='NaN',
+        ):
         """
         Draw a 3D scalar bar.
 
@@ -1173,9 +1277,9 @@ class BaseActor(Base3DProp):
 
         Return an ``Assembly`` object.
 
+        :param str title: scalar bar title
         :param float sx: thickness of scalarbar
         :param float sy: length of scalarbar
-        :param str title: scalar bar title
         :param float titleXOffset: horizontal space btw title and color scalarbar
         :param float titleYOffset: vertical space offset
         :param float titleSize: size of title wrt numeric labels
@@ -1192,10 +1296,10 @@ class BaseActor(Base3DProp):
         |mesh_coloring| |mesh_coloring.py|_
         """
         self.scalarbar = vedo.addons.addScalarBar3D(self,
+                                                    title,
                                                     pos,
                                                     sx,
                                                     sy,
-                                                    title,
                                                     titleFont,
                                                     titleXOffset,
                                                     titleYOffset,
@@ -1217,8 +1321,7 @@ class BaseActor(Base3DProp):
 
     def write(self, filename, binary=True):
         """Write object to file."""
-        import vedo.io as io
-        return io.write(self, filename, binary)
+        return vedo.io.write(self, filename, binary)
 
 
 ########################################################################################
@@ -1247,7 +1350,6 @@ class BaseGrid(BaseActor):
         can avoid flickering due to internal adjacent faces).
         If fill=False, only the boundary faces will be generated.
         """
-        from vedo.mesh import Mesh
         gf = vtk.vtkGeometryFilter()
         if fill:
             sf = vtk.vtkShrinkFilter()
@@ -1261,7 +1363,7 @@ class BaseGrid(BaseActor):
             gf.Update()
         poly = gf.GetOutput()
 
-        msh = Mesh(poly).flat()
+        msh = vedo.mesh.Mesh(poly).flat()
         msh.scalarbar = self.scalarbar
         lut = utils.ctf2lut(self)
         if lut:
@@ -1339,7 +1441,7 @@ class BaseGrid(BaseActor):
         return conn
 
 
-    def color(self, col):
+    def color(self, col, alpha=None):
         """
         Assign a color or a set of colors along the range of the scalar value.
         A single constant color can also be assigned.
@@ -1350,6 +1452,8 @@ class BaseGrid(BaseActor):
 
         ``volume.color(['red', 'violet', 'green'])``
         """
+        # superseeded in Points, Mesh
+
         smin, smax = self._data.GetScalarRange()
         ctf = self.GetProperty().GetRGBTransferFunction()
         ctf.RemoveAllPoints()
@@ -1362,7 +1466,8 @@ class BaseGrid(BaseActor):
                     r, g, b = colors.getColor(ci)
                     ctf.AddRGBPoint(x, r, g, b)
                     # colors.printc('color at', round(x, 1),
-                    #               'set to', colors.getColorName((r, g, b)), c='w', bold=0)
+                    #               'set to', colors.getColorName((r, g, b)),
+                    #               c='w', bold=0)
             else:
                 # user passing [color1, color2, ..]
                 for i, ci in enumerate(col):
@@ -1374,7 +1479,7 @@ class BaseGrid(BaseActor):
                 r, g, b = colors.getColor(col)
                 ctf.AddRGBPoint(smin, r,g,b) # constant color
                 ctf.AddRGBPoint(smax, r,g,b)
-            elif colors._mapscales:
+            else: # assume it's a colormap
                 for x in np.linspace(smin, smax, num=64, endpoint=True):
                     r,g,b = colors.colorMap(x, name=col, vmin=smin, vmax=smax)
                     ctf.AddRGBPoint(x, r, g, b)
@@ -1383,7 +1488,10 @@ class BaseGrid(BaseActor):
             ctf.AddRGBPoint(smin, r,g,b) # constant color
             ctf.AddRGBPoint(smax, r,g,b)
         else:
-            colors.printc("ugrid.color(): unknown input type:", col, c='r')
+            colors.printc("color(): unknown input type:", col, c='r')
+
+        if alpha is not None:
+            self.alpha(alpha)
         return self
 
     def alpha(self, alpha):
@@ -1413,15 +1521,16 @@ class BaseGrid(BaseActor):
                     xalpha = smin + (smax - smin) * i / (len(alpha) - 1)
                     # Create transfer mapping scalar value to opacity
                     otf.AddPoint(xalpha, al)
+                    #colors.printc("alpha at", round(xalpha, 1), "\tset to", al)
             elif len(alpha.shape)==2: # user passing [(x0,alpha0), ...]
                 otf.AddPoint(smin, alpha[0][1])
                 for xalpha, al in alpha:
                     # Create transfer mapping scalar value to opacity
                     otf.AddPoint(xalpha, al)
                 otf.AddPoint(smax, alpha[-1][1])
-            #colors.printc("alpha at", round(xalpha, 1), "\tset to", al)
 
         else:
+
             otf.AddPoint(smin, alpha) # constant alpha
             otf.AddPoint(smax, alpha)
 
@@ -1460,7 +1569,6 @@ class BaseGrid(BaseActor):
 
         |isosurfaces| |isosurfaces.py|_
         """
-        from vedo.mesh import Mesh
         scrange = self._data.GetScalarRange()
         cf = vtk.vtkContourFilter()
         cf.SetInputData(self._data)
@@ -1486,7 +1594,7 @@ class BaseGrid(BaseActor):
             conn.Update()
             poly = conn.GetOutput()
 
-        a = Mesh(poly, c=None).phong()
+        a = vedo.mesh.Mesh(poly, c=None).phong()
         a._mapper.SetScalarRange(scrange[0], scrange[1])
         return a
 
@@ -1503,7 +1611,6 @@ class BaseGrid(BaseActor):
 
         |legosurface| |legosurface.py|_
         """
-        from vedo.mesh import Mesh
         dataset = vtk.vtkImplicitDataSet()
         dataset.SetDataSet(self._data)
         window = vtk.vtkImplicitWindowFunction()
@@ -1530,7 +1637,7 @@ class BaseGrid(BaseActor):
         gf.SetInputData(extract.GetOutput())
         gf.Update()
 
-        a = Mesh(gf.GetOutput()).lw(0.1).flat().lighting('plastic')
+        a = vedo.mesh.Mesh(gf.GetOutput()).lw(0.1).flat().lighting('plastic')
         scalars = a.getPointArray()
         if scalars is None:
             print("Error in legosurface(): no scalars found!")
@@ -1660,13 +1767,11 @@ class BaseGrid(BaseActor):
                 tmesh = tetralize(ug)
                 tmesh.write('ugrid.vtu').show(axes=1)
         """
-        from vedo.tetmesh import tetralize
-        return tetralize(self._data, tetsOnly)
+        return vedo.tetmesh.tetralize(self._data, tetsOnly)
 
 
     def extractCellsByID(self, idlist, usePointIDs=False):
         """Return a new UGrid composed of the specified subset of indices."""
-        from vedo.ugrid import UGrid
         selectionNode = vtk.vtkSelectionNode()
         if usePointIDs:
             selectionNode.SetFieldType(vtk.vtkSelectionNode.POINT)
@@ -1683,7 +1788,7 @@ class BaseGrid(BaseActor):
         es.SetInputData(0, self._data)
         es.SetInputData(1, selection)
         es.Update()
-        tm_sel = UGrid(es.GetOutput())
+        tm_sel = vedo.ugrid.UGrid(es.GetOutput())
         pr = vtk.vtkProperty()
         pr.DeepCopy(self.GetProperty())
         tm_sel.SetProperty(pr)
@@ -2045,7 +2150,7 @@ def streamLines(domain, probe,
 
     sta = vedo.mesh.Mesh(output, c=None)
 
-    if lw is not None and len(tubes)==0 and not ribbons:
+    if lw is not None and len(tubes) == 0 and not ribbons:
         sta.lw(lw)
         sta._mapper.SetResolveCoincidentTopologyToPolygonOffset()
         sta.lighting('off')
