@@ -1,5 +1,3 @@
-from __future__ import division, print_function
-
 import vtk
 from vtk.util.numpy_support import numpy_to_vtk
 
@@ -13,14 +11,14 @@ import vedo.docs as docs
 from vedo.colors import printc
 
 import vedo.settings as settings
-from vedo.settings import datadir, embedWindow
+from vedo.settings import datadir, dataurl, embedWindow
 
 from vedo.mesh import Mesh
 
 from vedo.io import load, screenshot, Video, exportWindow, download
 
 import vedo.shapes as shapes
-from vedo.shapes import Text, Text2D, Latex
+from vedo.shapes import Text3D, Text2D, Latex
 
 from vedo.plotter import show, clear, Plotter
 from vedo.plotter import closeWindow, closePlotter, interactive
@@ -41,9 +39,9 @@ Basic example:
     .. code-block:: python
 
         import dolfin
-        from vedo.dolfin import datadir, plot
+        from vedo.dolfin import dataurl, plot
 
-        mesh = dolfin.Mesh(datadir+"dolfin_fine.xml")
+        mesh = dolfin.Mesh(dataurl+"dolfin_fine.xml")
 
         plot(mesh)
 
@@ -95,7 +93,7 @@ Image Gallery
 +-------------------------------------------------+-------------------------------------------------+
 | A soft beam deforming under its own weight      | The 1D wave eq. with the Crank Nicolson method  |
 +-------------------------------------------------+-------------------------------------------------+
-| |customAxes|                                    | |awefem|                                        |
+| |customAxes1|                                   | |awefem|                                        |
 +-------------------------------------------------+-------------------------------------------------+
 | Customizing axes style and appearance           |The wave equation in arbitrary nr. of dimensions |
 +-------------------------------------------------+-------------------------------------------------+
@@ -114,10 +112,11 @@ __all__ = [
     "printHistogram",
     "Plotter",
     "ProgressBar",
-    "Text",
+    "Text3D",
     "Text2D",
     "Latex",
     "datadir",
+    "dataurl",
     "screenshot",
     "Video",
     "exportWindow",
@@ -128,66 +127,9 @@ __all__ = [
 ]
 
 
-def _inputsort_dolfinx(obj): # dolfinx
-    import dolfin
-
-    u = None
-    mesh = None
-    if not utils.isSequence(obj):
-        obj = [obj]
-
-    for ob in obj:
-        inputtype = str(type(ob))
-        #print('inputtype is', inputtype)
-
-        if "vtk" in inputtype: # skip vtk objects, will be added later
-            continue
-
-        if "dolfin" in inputtype or "ufl" in inputtype:
-            if "MeshFunction" in inputtype:
-                mesh = ob.mesh # dolfin 2019.2
-
-                if ob.dim > 0:
-                    print('MeshFunction of dim>0 not supported.')
-                    print('Try e.g.:  MeshFunction("size_t", mesh, 0)')
-                    print('instead of MeshFunction("size_t", mesh, 1)')
-                else:
-                    #print(ob.dim, mesh.num_cells, len(mesh.coordinates, len(ob.array()))
-                    V = dolfin.FunctionSpace(mesh, "CG", 1)
-                    u = dolfin.Function(V)
-                    v2d = dolfin.vertex_to_dof_map(V)
-                    u.vector[v2d] = ob.array
-            elif "Function" in inputtype or "Expression" in inputtype:
-                u = ob
-                mesh = ob.function_space.mesh
-            elif "Mesh" in inputtype:
-                mesh = ob
-            elif "algebra" in inputtype:
-                mesh = ob.ufl_domain
-                #print('algebra', ob.ufl_domain)
-
-        if "str" in inputtype:
-            mesh = dolfin.Mesh(ob)
-
-    if u and not mesh and hasattr(u, "function_space"):
-        V = u.function_space
-        if V:
-            mesh = V.mesh
-
-    if u and not mesh and hasattr(u, "mesh"):
-        mesh = u.function_space.mesh
-
-    print('------------------------------------')
-    print('mesh.topology dim=', mesh.topology.dim)
-    print('mesh.geometry dim=', mesh.geometry.dim)
-    if u: print('u.value_rank', u.value_rank)
-    if u and u.value_rank: print('u.value_dimension', u.value_dimension(0)) # axis=0
-    if u: print('u.value_shape', u.value_shape())
-    return (mesh, u)
-
-
 ##########################################################################
 def _inputsort(obj):
+# def _inputsort_dolfin(obj):
     import dolfin
 
     u = None
@@ -355,7 +297,7 @@ def plot(*inputobj, **options):
         - scalarRange, (list) - scalar range of coloring
 
 
-   :param float warpZfactor: elevate z-axis by scalar value (useful for 2D geometries)
+    :param float warpZfactor: elevate z-axis by scalar value (useful for 2D geometries)
     :param float warpYfactor: elevate z-axis by scalar value (useful for 1D geometries)
 
     :param list scaleMeshFactors: rescale mesh by these factors [1,1,1]
@@ -394,54 +336,7 @@ def plot(*inputobj, **options):
        - 11, show a large grid on the x-y plane (use with zoom=8)
        - 12, show polar axes.
 
-    Axes type-1 can be fully customized by passing a dictionary ``axes=dict()`` where:
-
-        - `xtitle`,                ['x'], x-axis title text
-        - `xrange`,               [None], x-axis range in format (xmin, ymin), default is automatic.
-        - `numberOfDivisions`,    [None], approximate number of divisions on the longest axis
-        - `axesLineWidth`,           [1], width of the axes lines
-        - `gridLineWidth`,           [1], width of the grid lines
-        - `reorientShortTitle`,   [True], titles shorter than 2 letter are placed horizontally
-        - `titleDepth`,              [0], extrusion fractional depth of title text
-        - `xyGrid`,               [True], show a gridded wall on plane xy
-        - `yzGrid`,               [True], show a gridded wall on plane yz
-        - `zxGrid`,               [True], show a gridded wall on plane zx
-        - `zxGrid2`,             [False], show zx plane on opposite side of the bounding box
-        - `xyGridTransparent`    [False], make grid plane completely transparent
-        - `xyGrid2Transparent`   [False], make grid plane completely transparent on opposite side box
-        - `xyPlaneColor`,       ['gray'], color of the plane
-        - `xyGridColor`,        ['gray'], grid line color
-        - `xyAlpha`,              [0.15], grid plane opacity
-        - `xyFrameLine`,          [None], add a frame for the plane
-        - `showTicks`,            [True], show major ticks
-        - `digits`,               [None], use this number of significant digits in scientific notation
-        - `titleFont`,              [''], font for axes titles
-        - `labelFont`,              [''], font for numeric labels
-        - `textScale`,             [1.0], global scaling factor for text elements (titles, labels)
-        - `xTitlePosition`,       [0.32], title fractional positions along axis
-        - `xTitleOffset`,         [0.05], title fractional offset distance from axis line
-        - `xTitleJustify`, ["top-right"], title justification
-        - `xTitleRotation`,          [0], add a rotation of the axis title
-        - `xTitleBox`,           [False], add a box around title text
-        - `xLineColor`,      [automatic], color of the x-axis
-        - `xTitleColor`,     [automatic], color of the axis title
-        - `xTitleBackfaceColor`,  [None],  color of axis title on its backface
-        - `xTitleSize`,          [0.025], size of the axis title
-        - 'xTitleItalic',            [0], a bool or float to make the font italic
-        - `xHighlightZero`,       [True], draw a line highlighting zero position if in range
-        - `xHighlightZeroColor`, [autom], color of the line highlighting the zero position
-        - `xTickLength`,         [0.005], radius of the major ticks
-        - `xTickThickness`,     [0.0025], thickness of the major ticks along their axis
-        - `xMinorTicks`,             [1], number of minor ticks between two major ticks
-        - `xValuesAndLabels`          [], assign custom tick positions and labels [(pos1, label1), ...]
-        - `xLabelColor`,     [automatic], color of numeric labels and ticks
-        - `xLabelPrecision`,         [2], nr. of significative digits to be shown
-        - `xLabelSize`,          [0.015], size of the numeric labels along axis
-        - 'xLabelRotation',          [0], rotate clockwise [1] or anticlockwise [-1] by 90 degrees
-        - 'xFlipText',           [False], flip axis title and numeric labels orientation
-        - `xLabelOffset`,        [0.025], offset of numeric labels
-        - `tipSize`,              [0.01], size of the arrow tip
-        - `limitRatio`,           [0.04], below this ratio don't plot small axis
+    Axes type-1 can be fully customized by passing a dictionary ``axes=dict()``.
 
     :param bool infinity: if True fugue point is set at infinity (no perspective effects)
     :param bool sharecam: if False each renderer will have an independent vtkCamera
@@ -573,7 +468,6 @@ def plot(*inputobj, **options):
 
 
     # change some default to emulate standard behaviours
-    options['verbose'] = False # don't disturb
     if  style == 0 or style == 'vtk':
         font = 'Courier'
         axes = options.pop('axes', None)
@@ -804,7 +698,7 @@ def plot(*inputobj, **options):
 
 ###################################################################################
 class MeshActor(Mesh):
-    """MeshActor, a vtkActor derived object for dolfin support."""
+    """MeshActor, a vedo.Mesh derived object for dolfin support."""
 
     def __init__(self, *inputobj, **options):
 
