@@ -1,17 +1,16 @@
-from __future__ import division, print_function
 import vtk
 from vtk.util.numpy_support import vtk_to_numpy
 import os
 import glob
 import numpy as np
+import time
 
+import vedo
 import vedo.utils as utils
 import vedo.colors as colors
 from vedo.assembly import Assembly
 from vedo.mesh import Mesh
 from vedo.pointcloud import Points
-from vedo.ugrid import UGrid
-from vedo.tetmesh import TetMesh
 from vedo.picture import Picture
 from vedo.volume import Volume
 import vedo.docs as docs
@@ -39,10 +38,12 @@ __all__ = [
     "exportWindow",
     "importWindow",
     "screenshot",
+    "ask",
     "Video",
 ]
 
 
+
 def load(inputobj, unpack=True, force=False):
     """
     Load ``Mesh``, ``Volume`` and ``Picture`` objects from file or from the web.
@@ -190,13 +191,24 @@ def _load_file(filename, unpack):
         actor = Volume(img)
 
         ################################################################# 2D images:
-    elif fl.endswith(".png") or fl.endswith(".jpg") or fl.endswith(".bmp") or fl.endswith(".jpeg"):
+    elif fl.endswith(".png") or fl.endswith(".jpg") \
+        or fl.endswith(".bmp") or fl.endswith(".jpeg") or fl.endswith(".gif"):
         if ".png" in fl:
             picr = vtk.vtkPNGReader()
         elif ".jpg" in fl or ".jpeg" in fl:
             picr = vtk.vtkJPEGReader()
         elif ".bmp" in fl:
             picr = vtk.vtkBMPReader()
+        elif ".gif" in fl:
+            from PIL import Image, ImageSequence
+            img = Image.open(filename)
+            frames = []
+            for frame in ImageSequence.Iterator(img):
+                a = np.array(frame.convert('RGB').getdata(), dtype=np.uint8)
+                a = a.reshape(frame.size[1], frame.size[0],3)
+                frames.append(Picture(a))
+            return frames
+
         picr.SetFileName(filename)
         picr.Update()
         actor = Picture(picr.GetOutput())  # object derived from vtk.vtkImageActor()
@@ -219,7 +231,7 @@ def _load_file(filename, unpack):
                 elif isinstance(b, vtk.vtkImageData):
                     acts.append(Volume(b))
                 elif isinstance(b, vtk.vtkUnstructuredGrid):
-                    acts.append(UGrid(b))
+                    acts.append(vedo.UGrid(b))
             return acts
         else:
             return mb
@@ -297,7 +309,7 @@ def _load_file(filename, unpack):
             return None
 
         if isinstance(routput, vtk.vtkUnstructuredGrid):
-            actor = TetMesh(routput)
+            actor = vedo.TetMesh(routput)
 
         else:
             actor = Mesh(routput)
@@ -305,6 +317,7 @@ def _load_file(filename, unpack):
                 actor.GetProperty().SetPointSize(4)
 
     actor.filename = filename
+    actor.fileSize, actor.created = fileInfo(filename)
     return actor
 
 
@@ -369,9 +382,23 @@ def gunzip(filename):
     return tmp_file.name
 
 
+def fileInfo(file_path):
+    sz, created= "", ""
+    if os.path.isfile(file_path):
+        file_info = os.stat(file_path)
+        num = file_info.st_size
+        for x in ['B', 'KB', 'MB', 'GB', 'TB']:
+            if num < 1024.0:
+                break
+            num /= 1024.0
+        sz =  "%3.1f%s" % (num, x)
+        created = time.ctime(os.path.getmtime(file_path))
+    return sz, created
+
+
 ###################################################################
 def loadStructuredPoints(filename):
-    """Load a ``vtkStructuredPoints`` object from file."""
+    """Load and return a ``vtkStructuredPoints`` object from file."""
     reader = vtk.vtkStructuredPointsReader()
     reader.SetFileName(filename)
     reader.Update()
@@ -379,7 +406,7 @@ def loadStructuredPoints(filename):
 
 
 def loadStructuredGrid(filename):
-    """Load a ``vtkStructuredGrid`` object from file."""
+    """Load and return a ``vtkStructuredGrid`` object from file."""
     if filename.endswith(".vts"):
         reader = vtk.vtkXMLStructuredGridReader()
     else:
@@ -390,7 +417,7 @@ def loadStructuredGrid(filename):
 
 
 def loadUnStructuredGrid(filename):
-    """Load a ``vtkunStructuredGrid`` object from file."""
+    """Load and return a ``vtkunStructuredGrid`` object from file."""
     if filename.endswith(".vtu"):
         reader = vtk.vtkXMLUnstructuredGridReader()
     else:
@@ -401,7 +428,7 @@ def loadUnStructuredGrid(filename):
 
 
 def loadRectilinearGrid(filename):
-    """Load a ``vtkRectilinearGrid`` object from file."""
+    """Load and return a ``vtkRectilinearGrid`` object from file."""
     if filename.endswith(".vtr"):
         reader = vtk.vtkXMLRectilinearGridReader()
     else:
@@ -711,6 +738,7 @@ def toNumpy(obj):
         adict['time'] = obj.time()
         adict['rendered_at'] = obj.renderedAt
         adict['position'] = obj.pos()
+        adict['info'] = obj.info
         m = np.eye(4)
         vm = obj.getTransform().GetMatrix()
         for i in [0, 1, 2, 3]:
@@ -730,7 +758,6 @@ def toNumpy(obj):
         adict['points'] = obj.points(transformed=False).astype(np.float32)
         poly = obj.polydata()
         adict['flagText'] = obj.flagText
-        adict['legend'] = obj._legend
 
         adict['cells'] = None
         if poly.GetNumberOfPolys():
@@ -847,28 +874,23 @@ def toNumpy(obj):
     elif isinstance(obj, Picture):
         adict['type'] = 'Picture'
         _fillcommon(obj, adict)
-        arr = vtk_to_numpy(obj.inputdata().GetPointData().GetScalars())
-        adict['array'] = arr
+        adict['array'] = vtk_to_numpy(obj.inputdata().GetPointData().GetScalars())
         adict['shape'] = obj.inputdata().GetDimensions()
+        print('toNumpy(): vedo.Picture', obj.shape, obj.GetPosition())
 
-    ######################################################## Annotation
-    elif isinstance(obj, vtk.vtkCornerAnnotation):
-        tx = ''
-        for i in range(8):
-            tx = obj.GetText(i)
-            if tx: break
-        if tx:
-            adict['type'] = 'Annotation'
-            #adict['rendered_at'] = obj.renderedAt
-            adict['text'] = obj.GetText(i)
-            adict['position'] = i
-            adict['color'] = obj.GetTextProperty().GetColor()
-            adict['font'] = obj.GetTextProperty().GetFontFamilyAsString()
-            if 'File' in adict['font']:
-                adict['font'] = os.path.basename(obj.GetTextProperty().GetFontFile()).split('.')[0]
-            adict['size']  = obj.GetNonlinearFontScaleFactor()
-            adict['bgcol'] = obj.GetTextProperty().GetBackgroundColor()
-            adict['alpha'] = obj.GetTextProperty().GetBackgroundOpacity()
+    ######################################################## Text2D
+    elif isinstance(obj, vedo.Text2D):
+        adict['type'] = 'Text2D'
+        adict['rendered_at'] = obj.renderedAt
+        adict['text'] = obj.text()
+        adict['position'] = obj.GetPosition()
+        adict['color'] = obj.property.GetColor()
+        adict['font'] =  obj.font()
+        adict['size']  = obj.property.GetFontSize()/22.5
+        adict['bgcol'] = obj.property.GetBackgroundColor()
+        adict['alpha'] = obj.property.GetBackgroundOpacity()
+        adict['frame'] = obj.property.GetFrame()
+        # print('toNumpy(): vedo.Text2D', obj.text()[:10], obj.font(), obj.GetPosition())
 
     else:
         pass
@@ -1047,17 +1069,25 @@ def loadNumpy(inobj):
             _loadcommon(vimg, d)
             objs.append(vimg)
 
-        ### Annotation
+        ### Text2D
+        elif 'text2d' == d['type'].lower():
+            t = vedo.shapes.Text2D(d['text'], font=d['font'], c=d['color'])
+            t.pos(d['position']).size(d['size'])
+            t.background(d['bgcol'], d['alpha'])
+            if d['frame']:
+                t.frame(d['bgcol'])
+            objs.append(t)
+
+        ### Annotation ## backward compatibility - will disappear
         elif 'annotation' == d['type'].lower():
             from vedo.shapes import Text2D
             pos = d['position']
-            t = Text2D(d['text'], pos=pos+1, font=d['font'], c=d['color'])
-            t.SetNonlinearFontScaleFactor(d['size'])
-            t.GetTextProperty().SetBackgroundColor(d['bgcol'])
-            t.GetTextProperty().SetBackgroundOpacity(d['alpha'])
-            t.GetTextProperty().SetFrameColor(d['bgcol'])
-            t.GetTextProperty().BoldOff()
-            objs.append(t)
+            if isinstance(pos, int):
+                pos = "top-left"
+                d['size'] *= 2.7
+            t = Text2D(d['text'], font=d['font'], c=d['color']).pos(pos)
+            t.background(d['bgcol'], d['alpha']).size(d['size']).frame(d['bgcol'])
+            objs.append(t) ## backward compatibility
 
     if len(objs) == 1:
         return objs[0]
@@ -1141,11 +1171,12 @@ def write(objct, fileoutput, binary=True):
     elif fr.endswith(".vtm"):
         g = vtk.vtkMultiBlockDataGroupFilter()
         for ob in objct:
-            if isinstance(ob, Points): # picks transformation
+            if isinstance(ob, (Points, Volume)): # picks transformation
                 ob = ob.polydata(True)
-            elif isinstance(ob, (vtk.vtkActor, vtk.vtkVolume)):
-                ob = ob.GetMapper().GetInput()
-            g.AddInputData(ob)
+                g.AddInputData(ob)
+            # elif isinstance(ob, (vtk.vtkActor, vtk.vtkVolume)):
+            #     ob = ob.GetMapper().GetInput()
+            #     g.AddInputData(ob)
         g.Update()
         mb = g.GetOutputDataObject(0)
         wri = vtk.vtkXMLMultiBlockDataWriter()
@@ -1393,20 +1424,15 @@ def exportWindow(fileoutput, binary=False):
         sdict['defaultFont'] = settings.defaultFont
         sdict['objects'] = []
 
-        allobjs = vp.getMeshes() + vp.getVolumes()
+        allobjs = vp.getMeshes(includeNonPickables=True) + vp.getVolumes(includeNonPickables=True)
         acts2d = vp.renderer.GetActors2D()
         acts2d.InitTraversal()
         for i in range(acts2d.GetNumberOfItems()):
             a = acts2d.GetNextItem()
-            if isinstance(a, vtk.vtkCornerAnnotation):
+            if isinstance(a, vedo.Text2D):
                 allobjs.append(a)
 
-        # ir = vp.renderers.index(vp.renderer)
-        # for a in vp.actors:
-        #     # because of vtkXYPlotActor is not wrapped
-        #     if hasattr(a, 'renderedAt') and ir in a.renderedAt:
-        #         allobjs.append(a)
-        # allobjs = list(set(allobjs)) # unique
+        allobjs = list(set(allobjs)) # make sure its unique
 
         for a in allobjs:
             sdict['objects'].append(toNumpy(a))
@@ -1458,7 +1484,8 @@ def exportWindow(fileoutput, binary=False):
         settings.notebookBackend = savebk
 
     else:
-        colors.printc("Export extensions is not supported.", c='r')
+        colors.printc("Export extension", fr.split('.')[-1],
+                      "is not supported.", c='r')
     return
 
 
@@ -1656,6 +1683,19 @@ def screenshot(filename="screenshot.png", scale=None, returnNumpy=False):
         writer.Write()
     return settings.plotter_instance
 
+def ask(*question, **kwarg):
+    """
+    Ask a question from command line. Return the answer as a string.
+    See function `printc()` for the description of the options.
+    """
+    kwarg.update({'end': ' '})
+    if 'invert' not in kwarg.keys():
+        kwarg.update({'invert': True})
+    if 'box' in kwarg.keys():
+        kwarg.update({'box': ''})
+    colors.printc(*question, **kwarg)
+    resp = input()
+    return resp
 
 class Video:
     """
@@ -1695,6 +1735,7 @@ class Video:
         fr = self.get_filename(str(len(self.frames)) + ".png")
         screenshot(fr)
         self.frames.append(fr)
+        return self
 
     def pause(self, pause=0):
         """Insert a `pause`, in seconds."""
@@ -1704,19 +1745,22 @@ class Video:
             fr2 = self.get_filename(str(len(self.frames)) + ".png")
             self.frames.append(fr2)
             os.system("cp -f %s %s" % (fr, fr2))
+        return self
 
 
     def action(self, elevation_range=(0,80),
                azimuth_range=(0,359),
                zoom=None,
-               cam1=None, cam2=None):
+               cam1=None, cam2=None,
+               resetcam=False,
+               ):
         """
         Automatic shooting of a static scene by specifying rotation and elevation ranges.
 
         :param list elevation_range: initial and final elevation angles
         :param list azimuth_range: initial and final azimuth angles
         :param float zoom: initial zooming
-        :param cam12: initial and final camera position, can be dictionary or a vtkCamera
+        :param cam1 cam2: initial and final camera position, can be dictionary or a vtkCamera
         """
         if not self.duration:
             self.duration = 5
@@ -1756,8 +1800,8 @@ class Video:
         if len(azimuth_range)==2:
             vp.camera.Azimuth(azimuth_range[0])
 
-        vp.show(resetcam=False, interactive=False)
-        vp.renderer.ResetCamera()
+        vp.show(resetcam=resetcam, interactive=False)
+        # if resetcam: vp.renderer.ResetCamera()
 
         n = self.fps * self.duration
         for i in range(int(n)):
@@ -1770,10 +1814,13 @@ class Video:
                     vp.camera.Azimuth((azimuth_range[1]-azimuth_range[0])/n)
             vp.show()
             self.addFrame()
+        return self
 
     def close(self):
-        """Render the video and write to file."""
-
+        """
+        Render the video and write to file.
+        Return the current Plotter instance.
+        """
         if self.duration:
             self.fps = len(self.frames) / float(self.duration)
             colors.printc("Recalculated video FPS to", round(self.fps, 3), c="m")
@@ -1820,6 +1867,6 @@ class Video:
                 colors.printc("could not find snapshots", c='r')
 
         self.tmp_dir.cleanup()
-        return
+        return settings.plotter_instance
 
 
