@@ -1,16 +1,13 @@
-from __future__ import division, print_function
 import numpy as np
 import os
 import vtk
-import vedo.colors as colors
-import vedo.docs as docs
-import vedo.settings as settings
-import vedo.utils as utils
+import vedo
+from vedo.colors import printc, getColor, colorMap
+from vedo.utils import isSequence, flatten, buildPolyData
 from vedo.pointcloud import Points
-
 from vtk.util.numpy_support import numpy_to_vtk, vtk_to_numpy
 
-__doc__ = ("""Submodule to manage polygonal meshes.""" + docs._defs)
+__doc__ = ("""Submodule to manage polygonal meshes.""" + vedo.docs._defs)
 
 __all__ = ["Mesh", "merge"]
 
@@ -26,13 +23,11 @@ def merge(*meshs):
         |thinplate_grid| |value-iteration|
     """
     acts = []
-    for a in utils.flatten(meshs):
+    for a in flatten(meshs):
         if a:
             acts += [a]
 
-    if len(acts) == 1:
-        return acts[0].clone()
-    elif len(acts) == 0:
+    if not acts:
         return None
 
     polyapp = vtk.vtkAppendPolyData()
@@ -42,6 +37,7 @@ def merge(*meshs):
         else:
             polyapp.AddInputData(a.polydata())
     polyapp.Update()
+
     msh = Mesh(polyapp.GetOutput())
     if isinstance(acts[0], vtk.vtkActor):
         cprp = vtk.vtkProperty()
@@ -87,17 +83,19 @@ class Mesh(Points):
     ):
         Points.__init__(self)
 
-        self._current_texture_name = '' # used by plotter._keypress
+        self.line_locator = None
+        self._current_texture_name = ''  # used by plotter._keypress
 
-        self._mapper.SetInterpolateScalarsBeforeMapping(settings.interpolateScalarsBeforeMapping)
+        self._mapper.SetInterpolateScalarsBeforeMapping(vedo.settings.interpolateScalarsBeforeMapping)
 
-        if settings.usePolygonOffset:
+        if vedo.settings.usePolygonOffset:
             self._mapper.SetResolveCoincidentTopologyToPolygonOffset()
-            pof, pou = settings.polygonOffsetFactor, settings.polygonOffsetUnits
+            pof, pou = vedo.settings.polygonOffsetFactor, vedo.settings.polygonOffsetUnits
             self._mapper.SetResolveCoincidentTopologyPolygonOffsetParameters(pof, pou)
 
         inputtype = str(type(inputobj))
 
+
         if inputobj is None:
             pass
 
@@ -121,7 +119,7 @@ class Mesh(Points):
             self._polydata = inputobj  # cache vtkPolyData and mapper for speed
 
         elif isinstance(inputobj, (vtk.vtkStructuredGrid, vtk.vtkRectilinearGrid)):
-            if settings.visibleGridEdges:
+            if vedo.settings.visibleGridEdges:
                 gf = vtk.vtkExtractEdges()
                 gf.SetInputData(inputobj)
             else:
@@ -131,18 +129,18 @@ class Mesh(Points):
             self._polydata = gf.GetOutput()
 
         elif "trimesh" in inputtype:
-            tact = utils.trimesh2vedo(inputobj, alphaPerCell=False)
+            tact = vedo.utils.trimesh2vedo(inputobj, alphaPerCell=False)
             self._polydata = tact.polydata()
 
         elif "meshio" in inputtype: # meshio-4.0.11
             if len(inputobj.cells):
-                mcells =[]
+                mcells = []
                 for cellblock in inputobj.cells:
                     if cellblock.type in ("triangle", "quad"):
                         mcells += cellblock.data.tolist()
-                self._polydata = utils.buildPolyData(inputobj.points, mcells)
+                self._polydata = buildPolyData(inputobj.points, mcells)
             else:
-                self._polydata = utils.buildPolyData(inputobj.points, None)
+                self._polydata = buildPolyData(inputobj.points, None)
             # add arrays:
             try:
                 if len(inputobj.point_data):
@@ -161,16 +159,19 @@ class Mesh(Points):
             except AssertionError:
                 print("Could not add meshio cell data, skip.")
 
-        elif utils.isSequence(inputobj):
+        elif "meshlab" in inputtype:
+            self._polydata = vedo.utils.meshlab2vedo(inputobj)
+
+        elif isSequence(inputobj):
             ninp = len(inputobj)
             if ninp == 0:
                 self._polydata = vtk.vtkPolyData()
-            elif ninp == 2: # assume [vertices, faces]
-                self._polydata = utils.buildPolyData(inputobj[0], inputobj[1])
-            else:           # assume [vertices] or vertices
-                self._polydata = utils.buildPolyData(inputobj, None)
+            elif ninp == 2:  # assume [vertices, faces]
+                self._polydata = buildPolyData(inputobj[0], inputobj[1])
+            else:            # assume [vertices] or vertices
+                self._polydata = buildPolyData(inputobj, None)
 
-        elif hasattr(inputobj, "GetOutput"): # passing vtk object
+        elif hasattr(inputobj, "GetOutput"):  # passing vtk object
             if hasattr(inputobj, "Update"): inputobj.Update()
             if isinstance(inputobj.GetOutput(), vtk.vtkPolyData):
                 self._polydata = inputobj.GetOutput()
@@ -181,8 +182,7 @@ class Mesh(Points):
                 self._polydata = gf.GetOutput()
 
         elif isinstance(inputobj, str):
-            from vedo.io import load
-            dataset = load(inputobj)
+            dataset = vedo.io.load(inputobj)
             self.filename = inputobj
             if "TetMesh" in str(type(dataset)):
                 self._polydata = dataset.tomesh().polydata()
@@ -190,12 +190,12 @@ class Mesh(Points):
                 self._polydata = dataset.polydata()
 
         else:
-            colors.printc("Error: cannot build mesh from type:\n", inputtype, c='r')
+            printc("Error: cannot build mesh from type:\n", inputtype, c='r')
             raise RuntimeError()
 
 
-        if settings.computeNormals is not None:
-            computeNormals = settings.computeNormals
+        if vedo.settings.computeNormals is not None:
+            computeNormals = vedo.settings.computeNormals
 
         if self._polydata:
             if computeNormals:
@@ -210,18 +210,16 @@ class Mesh(Points):
 
         self._mapper.SetInputData(self._polydata)
 
-        self.line_locator = None
-
         self._bfprop = None  # backface property holder
-        self._scals_idx = 0  # index of the active scalar changed from CLI
-        self._ligthingnr = 0
 
         prp = self.GetProperty()
         prp.SetInterpolationToPhong()
 
-        if settings.renderLinesAsTubes:
-            if hasattr(prp, 'RenderLinesAsTubesOn'):
+        if vedo.settings.renderLinesAsTubes:
+            try:
                 prp.RenderLinesAsTubesOn()
+            except:
+                pass
 
         # set the color by c or by scalar
         if self._polydata:
@@ -263,7 +261,11 @@ class Mesh(Points):
             if not arrexists:
                 if c is None:
                     c = "gold"
-                c = colors.getColor(c)
+                    c = getColor(c)
+                elif isinstance(c, float) and c<=1:
+                    c = colorMap(c, "rainbow", 0,1)
+                else:
+                    c = getColor(c)
                 prp.SetColor(c)
                 prp.SetAmbient(0.1)
                 prp.SetDiffuse(1)
@@ -333,7 +335,8 @@ class Mesh(Points):
 
 
     def faces(self):
-        """Get cell polygonal connectivity ids as a python ``list``.
+        """
+        Get cell polygonal connectivity ids as a python ``list``.
         The output format is: [[id0 ... idn], [id0 ... idm],  etc].
         """
         arr1d = vtk_to_numpy(self._polydata.GetPolys().GetData())
@@ -359,6 +362,10 @@ class Mesh(Points):
                     break
         return conn # cannot always make a numpy array of it!
 
+    def cells(self):
+        """Alias for ``faces()``."""
+        return self.faces()
+
 
     def lines(self, flat=False):
         """Get lines connectivity ids as a numpy array.
@@ -422,7 +429,10 @@ class Mesh(Points):
             return self
             ###########
 
-        if utils.isSequence(tname):
+        if 'https' in tname:
+            tname = vedo.io.download(tname)
+
+        if isSequence(tname):
             from PIL import Image
             from tempfile import NamedTemporaryFile
             tmp_file = NamedTemporaryFile()
@@ -436,8 +446,8 @@ class Mesh(Points):
             if not os.path.isfile(tname):
                 tname = str(self.filename).replace('.'+ext, '.jpg')
             if not os.path.isfile(tname):
-                colors.printc("Error in texture(): default texture file must be png or jpg",
-                              "\n e.g.", tname, c='r')
+                printc("Error in texture(): default texture file must be png or jpg",
+                       "\n e.g.", tname, c='r')
                 raise RuntimeError()
 
         if isinstance(tname, vtk.vtkTexture):
@@ -447,13 +457,13 @@ class Mesh(Points):
                 if not isinstance(tcoords, np.ndarray):
                     tcoords = np.array(tcoords)
                 if tcoords.ndim != 2:
-                    colors.printc('tcoords must be a 2-dimensional array', c='r')
+                    printc('tcoords must be a 2-dimensional array', c='r')
                     return self
                 if tcoords.shape[0] != pd.GetNumberOfPoints():
-                    colors.printc('Error in texture(): nr of texture coords must match nr of points', c='r')
+                    printc('Error in texture(): nr of texture coords must match nr of points', c='r')
                     return self
                 if tcoords.shape[1] != 2:
-                    colors.printc('Error in texture(): vector must have 2 components', c='r')
+                    printc('Error in texture(): vector must have 2 components', c='r')
                 tarr = numpy_to_vtk(np.ascontiguousarray(tcoords), deep=True)
                 tarr.SetName('TCoordinates')
                 pd.GetPointData().SetTCoords(tarr)
@@ -467,22 +477,22 @@ class Mesh(Points):
                     tc = tmapper.GetOutput().GetPointData().GetTCoords()
                     if scale or ushift or vshift:
                         ntc = vtk_to_numpy(tc)
-                        if scale: ntc *= scale
+                        if scale:  ntc *= scale
                         if ushift: ntc[:,0] += ushift
                         if vshift: ntc[:,1] += vshift
                         tc = numpy_to_vtk(tc, deep=True)
                     pd.GetPointData().SetTCoords(tc)
                     pd.GetPointData().Modified()
 
-            fn = settings.textures_path + tname + ".jpg"
+            fn = vedo.settings.textures_path + tname + ".jpg"
             if os.path.exists(tname):
                 fn = tname
             elif not os.path.exists(fn):
-                colors.printc("File does not exist or texture", tname,
-                              "not found in", settings.textures_path, c="r")
-                colors.printc("\pin Available built-in textures:", c="m", end=" ")
-                for ff in os.listdir(settings.textures_path):
-                    colors.printc(ff.split(".")[0], end=" ", c="m")
+                printc("File does not exist or texture", tname,
+                       "not found in", vedo.settings.textures_path, c="r")
+                printc("\tin Available built-in textures:", c="m", end=" ")
+                for ff in os.listdir(vedo.settings.textures_path):
+                    printc(ff.split(".")[0], end=" ", c="m")
                 print()
                 return self
 
@@ -494,7 +504,7 @@ class Mesh(Points):
             elif ".bmp" in fnl:
                 reader = vtk.vtkBMPReader()
             else:
-                colors.printc("Error in texture(): supported files, PNG, BMP or JPG", c="r")
+                printc("Error in texture(): supported files, PNG, BMP or JPG", c="r")
                 return self
             reader.SetFileName(fn)
             reader.Update()
@@ -600,13 +610,13 @@ class Mesh(Points):
             return self
 
         if self.GetProperty().GetOpacity() < 1:
-            #colors.printc("In backColor(): only active for alpha=1", c="y")
+            # printc("In backColor(): only active for alpha=1", c="y")
             return self
 
         if not backProp:
             backProp = vtk.vtkProperty()
 
-        backProp.SetDiffuseColor(colors.getColor(bc))
+        backProp.SetDiffuseColor(getColor(bc))
         backProp.SetOpacity(self.GetProperty().GetOpacity())
         self.SetBackfaceProperty(backProp)
         self._mapper.ScalarVisibilityOff()
@@ -641,7 +651,7 @@ class Mesh(Points):
                 self.color(lc)
                 return self
             self.GetProperty().EdgeVisibilityOn()
-            self.GetProperty().SetEdgeColor(colors.getColor(lc))
+            self.GetProperty().SetEdgeColor(getColor(lc))
         else:
             return self.GetProperty().GetEdgeColor()
         return self
@@ -650,9 +660,10 @@ class Mesh(Points):
         """Set/get color of mesh edges. Same as `lineColor()`."""
         return self.lineColor(lineColor)
 
-    def quality(self, measure=6, cmap='RdYlBu'):
+    def addQuality(self, measure=6, cmap='RdYlBu'):
         """
-        Calculate functions of quality of the elements of a triangular mesh.
+        Calculate functions of quality for the elements of a triangular mesh.
+        This method adds to the mesh a cell array named "Quality".
         See class `vtkMeshQuality <https://vtk.org/doc/nightly/html/classvtkMeshQuality.html>`_
         for explanation.
 
@@ -697,50 +708,40 @@ class Mesh(Points):
         qf.SaveCellQualityOn()
         qf.Update()
         pd = qf.GetOutput()
-        varr = pd.GetCellData().GetArray('Quality')
-        self.addCellArray(varr, "Quality")
-        self.cmap(cmap, "Quality", on='cells')
-        arr = vtk_to_numpy(pd.GetCellData().GetArray('Quality'))
-        return arr
+        self._update(pd)
+        self.cmap(cmap, input_array="Quality", on='cells')
+        return self
 
 
-    def volume(self, value=None):
+    def volume(self):
         """Get/set the volume occupied by mesh."""
         mass = vtk.vtkMassProperties()
         mass.SetGlobalWarningDisplay(0)
-        mass.SetInputData(self.polydata(False))
+        mass.SetInputData(self.polydata())
         mass.Update()
-        v = mass.GetVolume()
-        if value is not None:
-            if not v:
-                colors.printc("Volume is zero: cannot rescale.", c='r', end="")
-                colors.printc(" Consider adding mesh.triangulate()", c='r')
-                return self
-            self.scale(value / v)
-            return self
-        else:
-            return v
+        return mass.GetVolume()
 
-    def area(self, value=None):
+    def area(self):
         """Get/set the surface area of mesh.
 
         .. hint:: |largestregion.py|_
         """
         mass = vtk.vtkMassProperties()
         mass.SetGlobalWarningDisplay(0)
-        mass.SetInputData(self.polydata(False))
+        mass.SetInputData(self.polydata())
         mass.Update()
-        ar = mass.GetSurfaceArea()
-        if value is not None:
-            if not ar:
-                colors.printc("Area is zero: cannot rescale.", c='r', end="")
-                colors.printc(" Consider adding mesh.triangulate()", c='r')
-                return self
-            self.scale(value / ar)
-            return self
-        else:
-            return ar
+        return mass.GetSurfaceArea()
 
+    def isClosed(self):
+        """Return ``True`` if mesh is watertight."""
+        featureEdges = vtk.vtkFeatureEdges()
+        featureEdges.BoundaryEdgesOn()
+        featureEdges.FeatureEdgesOff()
+        featureEdges.NonManifoldEdgesOn()
+        featureEdges.SetInputData(self.polydata(False))
+        featureEdges.Update()
+        ne = featureEdges.GetOutput().GetNumberOfCells()
+        return not bool(ne)
 
     def distanceToMesh(self, mesh, signed=False, negate=False):
         '''
@@ -801,8 +802,8 @@ class Mesh(Points):
             two attributes ``mesh.base``, and ``mesh.top`` are already defined.
         """
         if self.base is None:
-            colors.printc('Error in stretch(): Please define vectors', c='r')
-            colors.printc('   mesh.base and mesh.top at creation.', c='r')
+            printc('Error in stretch(): Please define vectors', c='r')
+            printc('   mesh.base and mesh.top at creation.', c='r')
             raise RuntimeError()
 
         p1, p2 = self.base, self.top
@@ -834,7 +835,7 @@ class Mesh(Points):
     def crop(self,
              top=None, bottom=None, right=None, left=None, front=None, back=None,
              bounds=None,
-        ):
+             ):
         """Crop an ``Mesh`` object.
 
         :param float top:    fraction to crop from the top plane (positive z)
@@ -869,12 +870,12 @@ class Mesh(Points):
             if left:   x0 = x0 + left*dx
             bounds = (x0, x1, y0, y1, z0, z1)
         else:
-            if bounds[0] is None: bounds[0]=x0
-            if bounds[1] is None: bounds[1]=x1
-            if bounds[2] is None: bounds[2]=y0
-            if bounds[3] is None: bounds[3]=y1
-            if bounds[4] is None: bounds[4]=z0
-            if bounds[5] is None: bounds[5]=z1
+            if bounds[0] is None: bounds[0] = x0
+            if bounds[1] is None: bounds[1] = x1
+            if bounds[2] is None: bounds[2] = y0
+            if bounds[3] is None: bounds[3] = y1
+            if bounds[4] is None: bounds[4] = z0
+            if bounds[5] is None: bounds[5] = z1
         cu.SetBounds(bounds)
 
         clipper = vtk.vtkClipPolyData()
@@ -975,7 +976,6 @@ class Mesh(Points):
 
         :param bool invert: if True return cut off part of Mesh.
 
-        :Example:
         .. code-block:: python
 
             from vedo import *
@@ -987,8 +987,6 @@ class Mesh(Points):
             cube.cutWithMesh(iso).c('silver').alpha(1)
             show(iso, cube)
 
-        |cutWithMesh2|
-
         .. hint:: |cutWithMesh1.py|_ |cutAndCap.py|_
 
             |cutWithMesh1| |cutAndCap|
@@ -1046,30 +1044,53 @@ class Mesh(Points):
         return self
 
 
-    def cutWithPointLoop(self, points, invert=False):
+    def cutWithPointLoop(self,
+                          points,
+                          invert=False,
+                          on='points',
+                          includeBoundary=False,
+        ):
         """
         Cut an ``Mesh`` object with a set of points forming a closed loop.
+
+        :param bool invert: invert selection (inside-out)
+        :param str on: if 'cells' will extract the whole cells lying inside
+            (or outside) the point loop
+
+        :param bool includeBoundary: include cells lying exactly on the
+            boundary line. Only relevant on 'cells' mode.
         """
         if isinstance(points, Points):
             vpts = points.polydata().GetPoints()
             points = points.points()
         else:
             vpts = vtk.vtkPoints()
+            if len(points[0])==2: # make it 3d
+                points = np.asarray(points)
+                points = np.c_[points, np.zeros(len(points))]
             for p in points:
                 vpts.InsertNextPoint(p)
 
-        spol = vtk.vtkSelectPolyData()
-        spol.SetLoop(vpts)
-        spol.GenerateSelectionScalarsOn()
-        spol.GenerateUnselectedOutputOff()
-        spol.SetInputData(self.polydata())
-        spol.Update()
-
-        # use vtkClipDataSet to slice the grid with the polydata
-        clipper = vtk.vtkClipPolyData()
-        clipper.SetInputData(spol.GetOutput())
-        clipper.SetInsideOut(not invert)
-        clipper.SetValue(0.0)
+        if 'cell' in on:
+            ippd = vtk.vtkImplicitSelectionLoop()
+            ippd.SetLoop(vpts)
+            ippd.AutomaticNormalGenerationOn()
+            clipper = vtk.vtkExtractPolyDataGeometry()
+            clipper.SetInputData(self.polydata())
+            clipper.SetImplicitFunction(ippd)
+            clipper.SetExtractInside(not invert)
+            clipper.SetExtractBoundaryCells(includeBoundary)
+        else:
+            spol = vtk.vtkSelectPolyData()
+            spol.SetLoop(vpts)
+            spol.GenerateSelectionScalarsOn()
+            spol.GenerateUnselectedOutputOff()
+            spol.SetInputData(self.polydata())
+            spol.Update()
+            clipper = vtk.vtkClipPolyData()
+            clipper.SetInputData(spol.GetOutput())
+            clipper.SetInsideOut(not invert)
+            clipper.SetValue(0.0)
         clipper.Update()
         cpoly = clipper.GetOutput()
 
@@ -1196,12 +1217,12 @@ class Mesh(Points):
             return self._update(vct.GetOutput())
 
         else:
-            #colors.printc("Error in triangulate()")
+            #printc("Error in triangulate()")
             return self
 
 
 
-    def addCurvatureScalars(self, method=0, lut=None):
+    def addCurvatureScalars(self, method=0):
         """
         Add scalars to ``Mesh`` that contains the
         curvature calculated in three different ways.
@@ -1224,9 +1245,6 @@ class Mesh(Points):
         self._polydata = curve.GetOutput()
 
         self._mapper.SetInputData(self._polydata)
-        if lut:
-            self._mapper.SetLookupTable(lut)
-            self._mapper.SetUseLookupTableScalarRange(1)
         self._mapper.Update()
         self.Modified()
         self._mapper.ScalarVisibilityOn()
@@ -1273,7 +1291,7 @@ class Mesh(Points):
         self._mapper.ScalarVisibilityOn()
         return self
 
-    def addShadow(self, x=None, y=None, z=None, c=(0.5, 0.5, 0.5), alpha=1, culling=1):
+    def addShadow(self, x=None, y=None, z=None, c=(0.6,0.6,0.6), alpha=1, culling=1):
         """
         Generate a shadow out of an ``Mesh`` on one of the three Cartesian planes.
         The output is a new ``Mesh`` representing the shadow.
@@ -1343,7 +1361,7 @@ class Mesh(Points):
         elif method == 3:
             sdf = vtk.vtkButterflySubdivisionFilter()
         else:
-            colors.printc("Error in subdivide: unknown method.", c="r")
+            printc("Error in subdivide: unknown method.", c="r")
             raise RuntimeError()
         if method != 2:
             sdf.SetNumberOfSubdivisions(N)
@@ -1382,7 +1400,8 @@ class Mesh(Points):
             if self.GetTexture():
                 decimate.TCoordsAttributeOn()
             else:
-                decimate.SetVolumePreservation(True)
+                pass
+                # decimate.SetVolumePreservation(True)
         else:
             decimate = vtk.vtkDecimatePro()
             decimate.PreserveTopologyOn()
@@ -1395,7 +1414,8 @@ class Mesh(Points):
         decimate.Update()
         return self._update(decimate.GetOutput())
 
-    def smoothLaplacian(self, niter=15, relaxfact=0.1, edgeAngle=15, featureAngle=60):
+    def smoothLaplacian(self, niter=15, relaxfact=0.1, edgeAngle=15, featureAngle=60,
+                        boundary=False):
         """
         Adjust mesh point positions using `Laplacian` smoothing.
 
@@ -1418,13 +1438,14 @@ class Mesh(Points):
         smoothFilter.SetRelaxationFactor(relaxfact)
         smoothFilter.SetEdgeAngle(edgeAngle)
         smoothFilter.SetFeatureAngle(featureAngle)
-        smoothFilter.BoundarySmoothingOn()
+        smoothFilter.SetBoundarySmoothing(boundary)
         smoothFilter.FeatureEdgeSmoothingOn()
         smoothFilter.GenerateErrorScalarsOn()
         smoothFilter.Update()
         return self._update(smoothFilter.GetOutput())
 
-    def smoothWSinc(self, niter=15, passBand=0.1, edgeAngle=15, featureAngle=60):
+    def smoothWSinc(self, niter=15, passBand=0.1, edgeAngle=15, featureAngle=60,
+                    boundary=False):
         """
         Adjust mesh point positions using the `Windowed Sinc` function interpolation kernel.
 
@@ -1449,7 +1470,7 @@ class Mesh(Points):
         smoothFilter.NormalizeCoordinatesOn()
         smoothFilter.NonManifoldSmoothingOn()
         smoothFilter.FeatureEdgeSmoothingOn()
-        smoothFilter.BoundarySmoothingOn()
+        smoothFilter.SetBoundarySmoothing(boundary)
         smoothFilter.Update()
         return self._update(smoothFilter.GetOutput())
 
@@ -1664,15 +1685,15 @@ class Mesh(Points):
             self.line_locator.SetDataSet(self.polydata())
             self.line_locator.BuildLocator()
 
-#        t = vtk.mutable(tol)
-#        x = [0,0,0]
-#        pcoords = [0,0,0]
-#        subId = vtk.mutable(0)
-#        found = self.line_locator.IntersectWithLine(p0, p1, tol, t, x, pcoords, subId)
-#        if found:
-#            return [x]
-#        else:
-#            return []
+        # t = vtk.mutable(tol)
+        # x = [0,0,0]
+        # pcoords = [0,0,0]
+        # subId = vtk.mutable(0)
+        # found = self.line_locator.IntersectWithLine(p0, p1, tol, t, x, pcoords, subId)
+        # if found:
+        #     return [x]
+        # else:
+        #     return []
 
         intersectPoints = vtk.vtkPoints()
         self.line_locator.IntersectWithLine(p0, p1, intersectPoints, None)
@@ -1683,7 +1704,6 @@ class Mesh(Points):
             pts.append(intersection)
         return pts
 
-
     def silhouette(self, direction=None, borderEdges=True, featureAngle=False):
         """
         Return a new line ``Mesh`` which corresponds to the outer `silhouette`
@@ -1702,15 +1722,16 @@ class Mesh(Points):
         sil = vtk.vtkPolyDataSilhouette()
         sil.SetInputData(self.polydata())
         sil.SetBorderEdges(borderEdges)
-        if featureAngle == False:
+        if featureAngle is False:
             sil.SetEnableFeatureAngle(0)
         else:
             sil.SetEnableFeatureAngle(1)
             sil.SetFeatureAngle(featureAngle)
 
         if (direction is None
-            and settings.plotter_instance and settings.plotter_instance.camera):
-            sil.SetCamera(settings.plotter_instance.camera)
+            and vedo.settings.plotter_instance
+            and vedo.settings.plotter_instance.camera):
+            sil.SetCamera(vedo.settings.plotter_instance.camera)
             m = Mesh()
             m._mapper.SetInputConnection(sil.GetOutputPort())
 
@@ -1725,14 +1746,14 @@ class Mesh(Points):
             sil.Update()
             m = Mesh(sil.GetOutput())
 
-        elif utils.isSequence(direction):
+        elif isSequence(direction):
             sil.SetVector(direction)
             sil.SetDirectionToSpecifiedVector()
             sil.Update()
             m = Mesh(sil.GetOutput())
         else:
-            colors.printc('Error in silhouette(): direction is', [direction], c='r')
-            colors.printc(' render the scene with show() or specify camera/direction', c='r')
+            printc('Error in silhouette(): direction is', [direction], c='r')
+            printc(' render the scene with show() or specify camera/direction', c='r')
             return self
 
         m.lw(2).c((0,0,0)).lighting('off')
@@ -1754,12 +1775,12 @@ class Mesh(Points):
         if isinstance(cam, vtk.vtkCamera):
             self.SetCamera(cam)
         else:
-            # if settings.plotter_instance and settings.plotter_instance.camera:
-            #     self.SetCamera(settings.plotter_instance.camera)
-            # else:
-            self._set2actcam=True
-            # colors.printc("Error in followCamera(): needs an already rendered scene,", c='r')
-            # colors.printc("                         or passing a vtkCamera object.", c='r')
+            plt = vedo.settings.plotter_instance
+            if plt and plt.camera:
+                self.SetCamera(plt.camera)
+            else:
+                # postpone to show() call
+                self._set2actcam=True
         return self
 
 
@@ -1874,19 +1895,19 @@ class Mesh(Points):
 
         |extrude| |extrude.py|_
         """
-        if utils.isSequence(zshift):
-#            ms = [] # todo
-#            poly0 = self.clone().polydata()
-#            for i in range(len(zshift)-1):
-#                rf = vtk.vtkRotationalExtrusionFilter()
-#                rf.SetInputData(poly0)
-#                rf.SetResolution(res)
-#                rf.SetCapping(0)
-#                rf.SetAngle(rotation)
-#                rf.SetTranslation(zshift)
-#                rf.SetDeltaRadius(dR)
-#                rf.Update()
-#                poly1 = rf.GetOutput()
+        if isSequence(zshift):
+            #            ms = [] # todo
+            #            poly0 = self.clone().polydata()
+            #            for i in range(len(zshift)-1):
+            #                rf = vtk.vtkRotationalExtrusionFilter()
+            #                rf.SetInputData(poly0)
+            #                rf.SetResolution(res)
+            #                rf.SetCapping(0)
+            #                rf.SetAngle(rotation)
+            #                rf.SetTranslation(zshift)
+            #                rf.SetDeltaRadius(dR)
+            #                rf.Update()
+            #                poly1 = rf.GetOutput()
             return self
         else:
             rf = vtk.vtkRotationalExtrusionFilter()
@@ -1909,30 +1930,44 @@ class Mesh(Points):
             return m.computeNormals(cells=False).phong()
 
 
+    def addConnectivity(self):
+        """
+        Flag a mesh by connectivity: each disconnected region will receive a different Id.
+        You can access the array of ids through ``mesh.getPointArray("RegionId")``.
+        """
+        cf = vtk.vtkConnectivityFilter()
+        cf.SetInputData(self.polydata(False))
+        cf.SetExtractionModeToAllRegions()
+        cf.ColorRegionsOn()
+        cf.Update()
+        return self._update(cf.GetOutput())
+
+
     def splitByConnectivity(self, maxdepth=1000):
         """
         Split a mesh by connectivity and order the pieces by increasing area.
 
         :param int maxdepth: only consider this number of mesh parts.
 
+        :param bool addRegions
+
         |splitmesh| |splitmesh.py|_
         """
-        self.addIDs()
-        pd = self.polydata()
+        pd = self.polydata(False)
         cf = vtk.vtkConnectivityFilter()
         cf.SetInputData(pd)
         cf.SetExtractionModeToAllRegions()
         cf.ColorRegionsOn()
         cf.Update()
-        cpd = cf.GetOutput()
-        a = Mesh(cpd)
+        a = Mesh(cf.GetOutput())
         alist = []
 
-        for t in range(max(a.getPointArray("RegionId")) - 1):
+        for t in range(max(a.getPointArray("RegionId")) + 1):
             if t == maxdepth:
                 break
             suba = a.clone().threshold("RegionId", t - 0.1, t + 0.1)
             area = suba.area()
+            # print('splitByConnectivity  piece:', t, ' area:', area, ' N:',suba.N())
             alist.append([suba, area])
 
         alist.sort(key=lambda x: x[1])
@@ -2054,7 +2089,7 @@ class Mesh(Points):
         """
         dijkstra = vtk.vtkDijkstraGraphGeodesicPath()
 
-        if utils.isSequence(start):
+        if isSequence(start):
             cc = self.points()
             pa = Points(cc)
             start = pa.closestPoint(start, returnIds=True)
@@ -2087,15 +2122,3 @@ class Mesh(Points):
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
