@@ -1,13 +1,12 @@
-from __future__ import division, print_function
-
+import os
 import numpy as np
 import vtk
+import vedo
 import vedo.colors as colors
 import vedo.docs as docs
 import vedo.utils as utils
 import vedo.settings as settings
 from vtk.util.numpy_support import numpy_to_vtk
-from vedo.base import Base3DProp
 
 __doc__ = (
     """
@@ -20,64 +19,81 @@ __all__ = ["Picture"]
 
 
 #################################################
-class Picture(vtk.vtkImageActor, Base3DProp):
+class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
     """
     Derived class of ``vtkImageActor``. Used to represent 2D pictures.
     Can be instantiated with a path file name or with a numpy array.
 
+    Use `Picture.shape` to access the number of pixels in x and y.
+
     |rotateImage| |rotateImage.py|_
     """
     def __init__(self, obj=None):
         vtk.vtkImageActor.__init__(self)
-        Base3DProp.__init__(self)
+        vedo.base.Base3DProp.__init__(self)
 
-        if utils.isSequence(obj) and len(obj):
-            iac = vtk.vtkImageAppendComponents()
-            nchan = obj.shape[2] # get number of channels in inputimage (L/LA/RGB/RGBA)
-            for i in range(nchan):
-                #arr = np.flip(np.flip(array[:,:,i], 0), 0).ravel()
-                arr = np.flip(obj[:,:,i], 0).ravel()
+
+        if utils.isSequence(obj) and len(obj): # passing array
+            obj = np.asarray(obj)
+
+            if len(obj.shape) == 3: # has shape (nx,ny, ncolor_alpha_chan)
+                iac = vtk.vtkImageAppendComponents()
+                nchan = obj.shape[2] # get number of channels in inputimage (L/LA/RGB/RGBA)
+                for i in range(nchan):
+                    #arr = np.flip(np.flip(array[:,:,i], 0), 0).ravel()
+                    arr = np.flip(obj[:,:,i], 0).ravel()
+                    varb = numpy_to_vtk(arr, deep=True, array_type=vtk.VTK_UNSIGNED_CHAR)
+                    varb.SetName("RGBA")
+                    imgb = vtk.vtkImageData()
+                    imgb.SetDimensions(obj.shape[1], obj.shape[0], 1)
+                    imgb.GetPointData().SetScalars(varb)
+                    iac.AddInputData(imgb)
+                iac.Update()
+                img = iac.GetOutput()
+
+            elif len(obj.shape) == 2: # black and white
+                arr = np.flip(obj[:,:], 0).ravel()
                 varb = numpy_to_vtk(arr, deep=True, array_type=vtk.VTK_UNSIGNED_CHAR)
-                imgb = vtk.vtkImageData()
-                imgb.SetDimensions(obj.shape[1], obj.shape[0], 1)
-                imgb.GetPointData().SetScalars(varb)
-                iac.AddInputData(0, imgb)
-            iac.Update()
-            img = iac.GetOutput()
-            self.SetInputData(img)
+                varb.SetName("RGBA")
+                img = vtk.vtkImageData()
+                img.SetDimensions(obj.shape[1], obj.shape[0], 1)
+                img.GetPointData().SetScalars(varb)
 
         elif isinstance(obj, vtk.vtkImageData):
-            self.SetInputData(obj)
             img = obj
 
         elif isinstance(obj, str):
             if "https://" in obj:
-                import vedo.io as io
-                obj = io.download(obj, verbose=False)
+                obj = vedo.io.download(obj, verbose=False)
 
-            if   ".png" in obj:
+            if   ".png" in obj.lower():
                 picr = vtk.vtkPNGReader()
-            elif ".jpg" in obj or ".jpeg" in obj:
+            elif ".jpg" in obj.lower() or ".jpeg" in obj.lower():
                 picr = vtk.vtkJPEGReader()
-            elif ".bmp" in obj:
+            elif ".bmp" in obj.lower():
                 picr = vtk.vtkBMPReader()
-            elif ".tif" in obj:
+            elif ".tif" in obj.lower():
                 picr = vtk.vtkTIFFReader()
             else:
                 colors.printc("Cannot understand picture format", obj, c='r')
                 return
             picr.SetFileName(obj)
+            self.filename = obj
             picr.Update()
             img = picr.GetOutput()
-            self.SetInputData(img)
 
         else:
             img = vtk.vtkImageData()
-            self.SetInputData(img)
 
         self._data = img
+        self.SetInputData(img)
+
+        sx,sy,_ = img.GetDimensions()
+        self.shape = np.array([sx,sy])
+
         self._mapper = self.GetMapper()
 
+
     def inputdata(self):
         """Return the underlying ``vtkImagaData`` object."""
         return self._data
@@ -89,13 +105,27 @@ class Picture(vtk.vtkImageActor, Base3DProp):
         self._mapper.Modified()
         return self
 
+    def clone(self, transform=False):
+        """Return an exact copy of the input Picture.
+        If transform is True, it is given the same scaling and position."""
+        img = vtk.vtkImageData()
+        img.DeepCopy(self._data)
+        pic = Picture(img)
+        if transform:
+            # assign the same transformation to the copy
+            pic.SetOrigin(self.GetOrigin())
+            pic.SetScale(self.GetScale())
+            pic.SetOrientation(self.GetOrientation())
+            pic.SetPosition(self.GetPosition())
+        return pic
+
     def text(self, txt,
                    pos=(0,0,0),
                    s=1,
                    c=None,
                    alpha=1,
                    bg=None,
-                   font="Gula",
+                   font="Theemim",
                    dpi=500,
                    justify="bottom-left",
                    ):
@@ -133,7 +163,6 @@ class Picture(vtk.vtkImageActor, Base3DProp):
         elif font.lower() == "arial": tp.SetFontFamilyToArial()
         else:
             tp.SetFontFamily(vtk.VTK_FONT_FILE)
-            import os
             if font in settings.fonts:
                 tp.SetFontFile(settings.fonts_path + font + '.ttf')
             elif os.path.exists(font):
@@ -227,31 +256,33 @@ class Picture(vtk.vtkImageActor, Base3DProp):
         blf.Update()
         return self._update(blf.GetOutput())
 
-    def polygonize(self, threshold=None, flip=False):
+    def threshold(self, value=None, flip=False):
         """
         Create a polygonal Mesh from a Picture by filling regions with pixels
-        luminosity above a specified threshold.
+        luminosity above a specified value.
 
         Parameters
         ----------
-        threshold : float, optional
+        value : float, optional
             The default is None, e.i. 1/3 of the scalar range.
 
+        flip: bool, optional
+            Flip polygon orientations
+
         Returns
         -------
         Mesh
             A polygonal mesh.
         """
-        from vedo.mesh import Mesh
         mgf = vtk.vtkImageMagnitude()
         mgf.SetInputData(self._data)
         mgf.Update()
         msq = vtk.vtkMarchingSquares()
         msq.SetInputData(mgf.GetOutput())
-        if threshold is None:
+        if value is None:
             r0,r1 = self._data.GetScalarRange()
-            threshold = r0 + (r1-r0)/3
-        msq.SetValue(0, threshold)
+            value = r0 + (r1-r0)/3
+        msq.SetValue(0, value)
         msq.Update()
         if flip:
             rs = vtk.vtkReverseSense()
@@ -265,11 +296,19 @@ class Picture(vtk.vtkImageActor, Base3DProp):
         ctr = vtk.vtkContourTriangulator()
         ctr.SetInputData(output)
         ctr.Update()
-        return Mesh(ctr.GetOutput(), c='k').bc('t').lighting('off')
-
-
-
+        return vedo.Mesh(ctr.GetOutput(), c='k').bc('t').lighting('off')
 
 
+    def tomesh(self):
+        """
+        Convert an image to polygonal data (quads),
+        with each polygon vertex assigned a RGBA value.
+        """
+        dims = self._data.GetDimensions()
+        gr = vedo.shapes.Grid(sx=dims[0], sy=dims[1], resx=dims[0]-1, resy=dims[1]-1)
+        gr.pos(int(dims[0]/2), int(dims[1]/2)).pickable(True).wireframe(False).lw(0)
+        self._data.GetPointData().GetScalars().SetName("RGBA")
+        gr.inputdata().GetPointData().AddArray(self._data.GetPointData().GetScalars())
+        return gr
 
 
