@@ -1,4 +1,3 @@
-from __future__ import division, print_function
 import vtk
 import numpy as np
 from vtk.util.numpy_support import numpy_to_vtk, vtk_to_numpy
@@ -11,6 +10,7 @@ import vedo.shapes as shapes
 import vedo.addons as addons
 from vedo.assembly import Assembly
 from vedo.mesh import Mesh, merge
+from vedo.plotter import show # not used, but useful to import this
 
 __doc__ = """Plotting utility functions.""" + vedo.docs._defs
 
@@ -22,7 +22,9 @@ __all__ = [
     "violin",
     "whisker",
     "streamplot",
+    "matrix",
     "DirectedGraph",
+    "show",
 ]
 
 
@@ -36,7 +38,6 @@ class Plot(Assembly):
 
         Assembly.__init__(self, *objs)
 
-        self.xscale = 1  # will always be one
         self.yscale = 1
         self.aspect = 4 / 3.0
         self.cut = True  # todo
@@ -54,65 +55,70 @@ class Plot(Assembly):
         self.bins = []
         self.freqs = []
 
-        # self.ylog = False # todo
-        # self.args = []  # maybe useless
-        # self.data = None
 
-        self.modified = False
+    def ybounds(self, scaled=True):
+        if scaled:
+            return (self._y0lim/self.yscale, self._y1lim/self.yscale)
+        else:
+            return (self._y0lim, self._y1lim)
 
     def __iadd__(self, *objs):
         """
         Add object to plot with taking automatically into account the correct aspect ratio.
         """
-        # these will scale proportionally to keep their shape aspect ratio
+        # these types will scale proportionally to keep their native shape aspect ratio intact
         typs = (
-            shapes.Text,
+            shapes.Text3D,
             shapes.Polygon,
             shapes.Star,
             shapes.Disc,
             shapes.Ellipsoid,
             shapes.Latex,
             shapes.Sphere,
+            # shapes.Arrow2D,
             Assembly,
+            vedo.Picture,
         )
-        self.fixed_scale = np.min([self.xscale, self.yscale])
+        self.fixed_scale = np.min([1, self.yscale])
 
         objs = objs[0]  # make a list anyway
         if not utils.isSequence(objs):
             objs = [objs]
 
         if not utils.isSequence(objs[0]) and isinstance(objs[0], Plot):
+            # is adding another whole Plot # TO BE REVISED
             plot2 = objs[0]
+            plot_z = plot2.z() + (plot2._x1lim - plot2._x0lim)/1000 # add a small shift in z
+            # print(plot2.yscale, self.yscale)
             elems = plot2.unpack()
             objs2 = []
             for e in elems:
-                if e.name == "axes" or "Text" in e.name:
+                if e.name == "axes":
                     continue
-                if isinstance(e, typs):
-                    ec = e.clone()
-                    ec.SetScale(1, 1 / plot2.yscale * self.yscale, 1)
-                else:
-                    ec = e.clone()
-                    ec.SetScale(1, 1 / plot2.yscale * self.yscale, 1)
-                self.AddPart(ec)
+                ec = e.clone()
+                # remove plot2.yscale and apply self.yscale:
+                ec.SetScale(1, self.yscale/plot2.yscale, 1)
+                self.AddPart(ec.z(plot_z))
                 objs2.append(ec)
             objs = objs2
 
         else:
             # print('adding individual objects', len(objs))
             for a in objs:
-                self.AddPart(a)
                 if isinstance(a, typs):
                     # special scaling to preserve the aspect ratio
+                    # print('adding', a.name, 'fixed scale', self.fixed_scale)
                     a.scale(self.fixed_scale)
                 else:
-                    a.scale([self.xscale, self.yscale, 1])
+                    # print('adding', a.name, 'yscale', self.yscale)
+                    a.scale([1, self.yscale, 1])
                 py = a.y()
                 a.y(py * self.yscale)
+                self.AddPart(a)
 
         if self.cut:  # todo
             for a in objs:
-                if not a or a.name == "axes" or "Text" in a.name:
+                if not a or a.name == "axes":
                     continue
                 if self._y0lim is not None and hasattr(a, "cutWithPlane"):
                     a.cutWithPlane([0, self._y0lim, 0], [0, 1, 0])
@@ -123,7 +129,6 @@ class Plot(Assembly):
                 if self._x1lim is not None and hasattr(a, "cutWithPlane"):
                     a.cutWithPlane([self._x1lim, 0, 0], [-1, 0, 0])
 
-        self.modified = True
         return self
 
     def plot(self, *args, **kwargs):
@@ -192,11 +197,11 @@ def plot(*args, **kwargs):
 
     More examples:
 
-    |plot1_errbars| |plot1_errbars.py|_
+    |plot_errbars| |plot_errbars.py|_
 
-    |plot2_errband| |plot2_errband.py|_
+    |plot_errband| |plot_errband.py|_
 
-    |plot3_pip| |plot3_pip.py|_
+    |plot_pip| |plot_pip.py|_
 
     |scatter1| |scatter1.py|_
 
@@ -213,7 +218,7 @@ def plot(*args, **kwargs):
     :param bool showNan: show where the function does not exist as red points.
     :param list bins: number of bins in x and y.
 
-    |plot4_fxy| |plot4_fxy.py|_
+    |plot_fxy| |plot_fxy.py|_
 
     Function is: :math:`f(x,y)=\sin(3x) \cdot \log(x-y)/3` in range :math:`x=[0,3], y=[0,3]`.
 
@@ -224,7 +229,7 @@ def plot(*args, **kwargs):
     :param float lw: line with of the binning
     :param list bins: binning in x and y
 
-    |fcomplex| |plot4_fxy.py|_
+    |fcomplex| |plot_fxy.py|_
 
 
     If ``mode='polar'`` input arrays are interpreted as a list of polar angles and radii.
@@ -266,7 +271,7 @@ def plot(*args, **kwargs):
     :param alpha: transparency of the unit grid
     :param str cmap: color map of the surface
 
-    |plot5_spheric| |plot5_spheric.py|_
+    |plot_spheric| |plot_spheric.py|_
     """
     mode = kwargs.pop("mode", "")
     if "spher" in mode:
@@ -290,7 +295,6 @@ def plot(*args, **kwargs):
             kwargs["dashed"] = True
         elif "-" in opts:
             opts = opts.replace("-", "")
-            kwargs["lw"] = 2
         else:
             kwargs["lw"] = 0
         symbs = [".", "p", "*", "h", "D", "d", "o", "v", "^", ">", "<", "s", "x", "+", "a"]
@@ -351,6 +355,7 @@ def histogram(*args, **kwargs):
 
     :param int bins: number of bins.
     :param list vrange: restrict the range of the histogram.
+    :param bool density: normalize the area to 1 by dividing by the nr of entries and bin size.
     :param bool logscale: use logscale on y-axis.
     :param bool fill: fill bars woth solid color `c`.
     :param float gap: leave a small space btw bars.
@@ -438,7 +443,16 @@ def histogram(*args, **kwargs):
         return _histogram2D(args[0], args[1], **kwargs)
 
     elif len(args) == 1:
-        data = np.array(args[0])
+
+        if isinstance(args[0], vedo.Volume):
+            data = args[0].getDataArray().ravel()
+        elif isinstance(args[0], vedo.Points):
+            if args[0].getPointArray():
+                data = args[0].getPointArray().ravel()
+            else:
+                data = args[0].getCellArray().ravel()
+        else:
+            data = np.array(args[0])
 
         if "spher" in mode:
             return _histogramSpheric(args[0][:, 0], args[0][:, 1], **kwargs)
@@ -456,6 +470,163 @@ def histogram(*args, **kwargs):
     return None
 
 
+def fit(points,
+        deg=1,
+        niter=0,
+        nstd=3,
+        xerrors=None,
+        yerrors=None,
+        vrange=None,
+        res=250,
+        lw=3,
+        c='red4',
+    ):
+    """
+    Polynomial fitting in 2D with parameter error and error bands calculation.
+
+    Errors bars in both x and y are supported.
+
+    Additional information about the fitting output can be accessed. E.g.:
+
+        ``fit = fitPolynomial(pts)``
+
+        - ``fit.coefficients``: contains the coefficient of the polynomial fit
+        - ``fit.coefficientErrors``: errors on the fitting coefficients,
+            these numbers only make sense if parameters are not correlated
+
+        - ``fit.MonteCarloCoefficients``: fitting coefficient set from MC generation
+        - ``fit.covarianceMatrix``: covariance matrix as a numpy array
+        - ``fit.reducedChi2``: reduced chi-square of the fitting
+        - ``fit.ndof``: number of degrees of freedom
+        - ``fit.dataSigma``: mean data dispersion from the central fit assuming Chi2=1
+        - ``fit.errorLines``: a ``vedo.Line`` object for the upper and lower error band
+        - ``fit.errorBand``: the ``vedo.Mesh`` object representing the error band
+
+    Errors on x and y can be specified. If left `None` an estimate is made from
+    the statistical spread of the dataset itself. Errors are always assumed gaussian.
+
+    :param int deg: degree of the polynomial to be fitted
+    :param int niter: number of monte-carlo iterations to compute error bands.
+        If set to 0, return the simple least-squares fit with naive error estimation
+        on coefficients only. A reasonable non-zero value to set is about 500, in
+        this case ``errorLines``, ``errorBand`` and the other class attributes are filled
+
+    :param int nstd: nr. of standard deviation to use for error calculation
+    :param list xerrors: array of the same length of points with the errors on x
+    :param list yerrors: array of the same length of points with the errors on y
+    :param list vrange: specify the domain range of the fitting line
+        (only affects visualization, but can be used to extrapolate the fit
+         outside the data range)
+
+    :param int res: resolution of the output fitted line and error lines
+
+    |fitPolynomial1| |fitPolynomial1.py|_
+
+    |fitPolynomial2| |fitPolynomial2.py|_
+    """
+    if isinstance(points, vedo.pointcloud.Points):
+        points = points.points()
+    points = np.asarray(points)
+    if len(points) == 2: # assume user is passing [x,y]
+        points = np.c_[points[0],points[1]]
+    x = points[:,0]
+    y = points[:,1] # ignore z
+
+    n = len(x)
+    ndof = n - deg - 1
+    if vrange is not None:
+        x0, x1 = vrange
+    else:
+        x0, x1 = np.min(x), np.max(x)
+        if xerrors is not None:
+            x0 -= xerrors[0]/2
+            x1 += xerrors[-1]/2
+
+    tol = (x1-x0)/1000
+    xr = np.linspace(x0,x1, res)
+
+    # project x errs on y
+    if xerrors is not None:
+        xerrors = np.asarray(xerrors)
+        if yerrors is not None:
+            yerrors = np.asarray(yerrors)
+            w = 1.0/yerrors
+            coeffs = np.polyfit(x, y, deg, w=w, rcond=None)
+        else:
+            coeffs = np.polyfit(x, y, deg, rcond=None)
+        # update yerrors, 1 bootstrap iteration is enough
+        p1d = np.poly1d(coeffs)
+        der = (p1d(x+tol)-p1d(x))/tol
+        yerrors = np.sqrt(yerrors*yerrors + np.power(der*xerrors,2))
+
+    if yerrors is not None:
+        yerrors = np.asarray(yerrors)
+        w = 1.0/yerrors
+        coeffs, V = np.polyfit(x, y, deg, w=w, rcond=None, cov=True)
+    else:
+        w = 1
+        coeffs, V = np.polyfit(x, y, deg, rcond=None, cov=True)
+
+    p1d = np.poly1d(coeffs)
+    theor = p1d(xr)
+    l = shapes.Line(xr, theor, lw=lw, c=c).z(tol*2)
+    l.coefficients = coeffs
+    l.covarianceMatrix = V
+    residuals2_sum = np.sum(np.power(p1d(x)-y, 2))/ndof
+    sigma = np.sqrt(residuals2_sum)
+    l.reducedChi2 = np.sum(np.power((p1d(x)-y)*w, 2))/ndof
+    l.ndof = ndof
+    l.dataSigma = sigma # worked out from data using chi2=1 hypo
+    l.name = "LinePolynomialFit"
+
+    if not niter:
+        l.coefficientErrors = np.sqrt(np.diag(V))
+        return l ################################
+
+    if yerrors is not None:
+        sigma = yerrors
+    else:
+        w = None
+        l.reducedChi2 = 1
+
+    Theors, all_coeffs = [], []
+    for i in range(niter):
+        noise = np.random.randn(n)*sigma
+        Coeffs = np.polyfit(x, y + noise, deg, w=w, rcond=None)
+        all_coeffs.append(Coeffs)
+        P1d = np.poly1d(Coeffs)
+        Theor = P1d(xr)
+        Theors.append(Theor)
+    all_coeffs = np.array(all_coeffs)
+    l.MonteCarloCoefficients = all_coeffs
+
+    stds = np.std(Theors, axis=0)
+    l.coefficientErrors = np.std(all_coeffs, axis=0)
+
+    # check distributions on the fly
+    # for i in range(deg+1):
+    #     vedo.pyplot.histogram(all_coeffs[:,i],title='par'+str(i)).show(new=1)
+    # vedo.pyplot.histogram(all_coeffs[:,0], all_coeffs[:,1],
+    #                       xtitle='param0', ytitle='param1',scalarbar=1).show(new=1)
+    # vedo.pyplot.histogram(all_coeffs[:,1], all_coeffs[:,2],
+    #                       xtitle='param1', ytitle='param2').show(new=1)
+    # vedo.pyplot.histogram(all_coeffs[:,0], all_coeffs[:,2],
+    #                       xtitle='param0', ytitle='param2').show(new=1)
+
+    error_lines = []
+    for i in [nstd, -nstd]:
+        el = shapes.Line(xr, theor+stds*i, lw=1, alpha=0.2, c='k').z(tol)
+        error_lines.append(el)
+        el.name = "ErrorLine for sigma="+str(i)
+
+    l.errorLines = error_lines
+    l1 = error_lines[0].points().tolist()
+    cband = l1 + list(reversed(error_lines[1].points().tolist())) + [l1[0]]
+    l.errorBand = shapes.Line(cband).triangulate().lw(0).c('k', 0.15)
+    l.errorBand.name = "PolynomialFitErrorBand"
+    return l
+
+
 #########################################################################################
 def _plotxy(
     data,
@@ -492,7 +663,6 @@ def _plotxy(
     if marker == "" and not line and not spline:
         line = True
 
-
     # purge NaN from data
     validIds = np.all(np.logical_not(np.isnan(data)), axis=1)
     data = data[validIds]
@@ -662,13 +832,13 @@ def _plotxy(
     if title:
         if titleSize is None:
             titleSize = dx / 40.0
-        tit = shapes.Text(
+        tit = shapes.Text3D(
             title,
             s=titleSize,
             c=c,
             depth=0,
             alpha=alpha,
-            pos=((x0lim + x1lim) / 2, y1lim + dy / 80, 0),
+            pos=((x0lim + x1lim) / 2, y1lim + (y1lim-y0lim) / 80, 0),
             justify="bottom-center",
         )
         tit.pickable(False).z(3 * offs)
@@ -680,7 +850,7 @@ def _plotxy(
         ndiv = 6
         if "numberOfDivisions" in axes.keys():
             ndiv = axes["numberOfDivisions"]
-        tp, ts = utils.make_ticks(y0lim / yscale, y1lim / yscale, ndiv / aspect)
+        tp, ts = utils.makeTicks(y0lim / yscale, y1lim / yscale, ndiv / aspect)
         labs = []
         for i in range(1, len(tp) - 1):
             ynew = utils.linInterpolate(tp[i], [0, 1], [y0lim, y1lim])
@@ -693,14 +863,13 @@ def _plotxy(
         axes["yrange"] = (y0lim, y1lim)
         axes["zrange"] = (0, 0)
         axes["c"] = "k"
+        axes["yUseBounds"] = True
         axs = addons.Axes(**axes)
         axs.name = "axes"
         asse = Plot(acts, axs)
         asse.axes = axs
         asse.SetOrigin(x0lim, y0lim, 0)
-        # print('yscale =    ', yscale)
-        # print('y0,    y1   ', y0, y1)
-        # print('y0lim, y1lim', y0lim, y1lim)
+
     else:
         settings.xtitle = xtitle
         settings.ytitle = ytitle
@@ -799,7 +968,7 @@ def _plotFxy(
         poly = a.polydata()
 
     cmap=''
-    if c in colors._mapscales_cmaps:
+    if c in colors.cmaps_names:
         cmap = c
         c = None
         bc= None
@@ -1003,7 +1172,7 @@ def _plotPolar(
 
     ti = None
     if title:
-        ti = shapes.Text(title, (0, 0, 0), s=tsize, depth=0, justify="top-center")
+        ti = shapes.Text3D(title, (0, 0, 0), s=tsize, depth=0, justify="top-center")
         ti.pos(0, -r2e * 1.15, 0.01)
 
     rays = []
@@ -1037,7 +1206,7 @@ def _plotPolar(
                     ju = "top-center"
                 else:
                     ju = "top-left"
-                a = shapes.Text(int(t * k), pos=(0, 0, 0), s=lsize, depth=0, justify=ju)
+                a = shapes.Text3D(int(t * k), pos=(0, 0, 0), s=lsize, depth=0, justify=ju)
                 a.pos(r2e * ct * (1 + rgap), r2e * st * (1 + rgap), -0.01)
                 angles.append(a)
 
@@ -1112,7 +1281,7 @@ def _histogram1D(
     data,
     format=None,
     bins=25,
-    aspect=4 / 3,
+    aspect=4/3,
     xlim=None,
     ylim=(0,None),
     errors=False,
@@ -1121,6 +1290,7 @@ def _histogram1D(
     ytitle="counts",
     titleSize=None,
     titleColor=None,
+    density=False,
     logscale=False,
     fill=True,
     c="olivedrab",
@@ -1156,10 +1326,16 @@ def _histogram1D(
 
     fs, edges = np.histogram(data, bins=bins, range=xlim)
     # print('frequencies', fs)
-    if logscale:
+    if density:
+        ntot = len(data.ravel())
+        binsize = edges[1]-edges[0]
+        fs = fs/(ntot*binsize)
+        if ytitle=='counts':
+            ytitle=f"counts/({ntot}~\dot~{utils.precision(binsize,3)})"
+    elif logscale:
         fs = np.log10(fs + 1)
         if ytitle=='counts':
-            ytitle='log(counts)'
+            ytitle='log_10 (counts+1)'
 
     x0, x1 = np.min(edges), np.max(edges)
     y0, y1 = 0, np.max(fs)
@@ -1229,7 +1405,11 @@ def _histogram1D(
             r = shapes.Rectangle(p0, p1)
             r.origin(p0).PickableOff()
             maxheigth = max(maxheigth, p1[1])
-            r.color(c).alpha(alpha).lighting('off').z(offs)
+            if c in colors.cmaps_names:
+                col = colors.colorMap((p0[0]+p1[0])/2, c, myedges[0], myedges[-1])
+            else:
+                col = c
+            r.color(col).alpha(alpha).lighting('off').z(offs)
             rs.append(r)
         # print('rectangles', r.z())
 
@@ -1308,13 +1488,13 @@ def _histogram1D(
 
         if titleSize is None:
             titleSize = dx / 40.0
-        tit = shapes.Text(
+        tit = shapes.Text3D(
             title,
             s=titleSize,
             c=titleColor,
             depth=0,
             alpha=alpha,
-            pos=((x0lim + x1lim) / 2, y1lim + dy / 80, 0),
+            pos=((x0lim + x1lim) / 2, y1lim + (y1lim-y0lim) / 80, 0),
             justify="bottom-center",
         )
         tit.pickable(False).z(2.5 * offs)
@@ -1326,7 +1506,7 @@ def _histogram1D(
         ndiv = 6
         if "numberOfDivisions" in axes.keys():
             ndiv = axes["numberOfDivisions"]
-        tp, ts = utils.make_ticks(y0lim / yscale, y1lim / yscale, ndiv / aspect)
+        tp, ts = utils.makeTicks(y0lim / yscale, y1lim / yscale, ndiv / aspect)
         labs = []
         for i in range(1, len(tp) - 1):
             ynew = utils.linInterpolate(tp[i], [0, 1], [y0lim, y1lim])
@@ -1381,6 +1561,7 @@ def _histogram2D(
     title="",
     xtitle="x",
     ytitle="y",
+    ztitle="z",
     titleSize=None,
     titleColor=None,
     # logscale=False,
@@ -1400,6 +1581,7 @@ def _histogram2D(
         title = ""
         xtitle = ""
         ytitle = ""
+        ztitle = ""
         offs = format.zmax
 
     if yvalues is None:
@@ -1440,7 +1622,7 @@ def _histogram2D(
     g.cmap(cmap, np.ravel(H.T), on='cells')
     g.SetOrigin(x0lim, y0lim, 0)
     if scalarbar:
-        sc = g.addScalarBar3D(c=bc)
+        sc = g.addScalarBar3D(c=bc).scalarbar
         scy0, scy1 = sc.ybounds()
         sc_scale = (y1lim-y0lim)/(scy1-scy0)
         sc.scale(sc_scale)
@@ -1455,13 +1637,13 @@ def _histogram2D(
 
         if titleSize is None:
             titleSize = dx / 40.0
-        tit = shapes.Text(
+        tit = shapes.Text3D(
             title,
             s=titleSize,
             c=titleColor,
             depth=0,
             alpha=alpha,
-            pos=((x0lim + x1lim) / 2, y1lim + dy / 40, 0),
+            pos=((x0lim + x1lim) / 2, y1lim + (y1lim-y0lim) / 80, 0),
             justify="bottom-center",
         )
         tit.pickable(False).z(2.5 * offs)
@@ -1473,17 +1655,18 @@ def _histogram2D(
         ndiv = 6
         if "numberOfDivisions" in axes.keys():
             ndiv = axes["numberOfDivisions"]
-        tp, ts = utils.make_ticks(y0lim / yscale, y1lim / yscale, ndiv / aspect)
+        tp, ts = utils.makeTicks(y0lim / yscale, y1lim / yscale, ndiv / aspect)
         labs = []
         for i in range(1, len(tp) - 1):
             ynew = utils.linInterpolate(tp[i], [0, 1], [y0lim, y1lim])
             labs.append([ynew, ts[i]])
         axes["xtitle"] = xtitle
         axes["ytitle"] = ytitle
+        axes["ztitle"] = ztitle
         axes["yValuesAndLabels"] = labs
         axes["xrange"] = (x0lim, x1lim)
         axes["yrange"] = (y0lim, y1lim)
-        axes["zrange"] = (0, 0)
+        axes["zrange"] = (0, 0) # todo
         axes["c"] = bc
         axs = addons.Axes(**axes)
         axs.name = "axes"
@@ -1493,6 +1676,7 @@ def _histogram2D(
     else:
         settings.xtitle = xtitle
         settings.ytitle = ytitle
+        settings.ytitle = ztitle
         asse = Plot(acts)
 
     asse.yscale = yscale
@@ -1518,6 +1702,7 @@ def _histogramHexBin(
     yvalues,
     xtitle="",
     ytitle="",
+    ztitle="",
     bins=12,
     vrange=None,
     norm=1,
@@ -1530,6 +1715,8 @@ def _histogramHexBin(
         settings.xtitle = xtitle
     if ytitle:
         settings.ytitle = ytitle
+    if ztitle:
+        settings.ztitle = ztitle
 
     xmin, xmax = np.min(xvalues), np.max(xvalues)
     ymin, ymax = np.min(yvalues), np.max(yvalues)
@@ -1576,7 +1763,7 @@ def _histogramHexBin(
             else:
                 p = (i / ki, j / kj + 0.45, 0)
             q = (p[0] / n * 1.2 * dx + xmin, p[1] / m * dy + ymin, 0)
-            ids = cloud.closestPoint(q, radius=r, returnIds=True)
+            ids = cloud.closestPoint(q, radius=r, returnCellId=True)
             ne = len(ids)
             if fill:
                 t.Translate(p[0], p[1], ne / 2)
@@ -1748,18 +1935,18 @@ def _histogramPolar(
                     ju = "top-center"
                 else:
                     ju = "top-left"
-                a = shapes.Text(int(t * k), pos=(0, 0, 0), s=lsize, depth=0, justify=ju)
+                a = shapes.Text3D(int(t * k), pos=(0, 0, 0), s=lsize, depth=0, justify=ju)
                 a.pos(r2e * ct * (1 + rgap), r2e * st * (1 + rgap), -0.01)
                 angles.append(a)
 
     ti = None
     if title:
-        ti = shapes.Text(title, (0, 0, 0), s=tsize, depth=0, justify="top-center")
+        ti = shapes.Text3D(title, (0, 0, 0), s=tsize, depth=0, justify="top-center")
         ti.pos(0, -r2e * 1.15, 0.01)
 
     for i,t in enumerate(thetas):
         if i < len(labels):
-            lab = shapes.Text(labels[i], (0, 0, 0), #font="VTK",
+            lab = shapes.Text3D(labels[i], (0, 0, 0), #font="VTK",
                               s=lsize, depth=0, justify="center")
             lab.pos(r2e *np.cos(t) * (1 + rgap) * lpos / 2,
                     r2e *np.sin(t) * (1 + rgap) * lpos / 2, 0.01)
@@ -1803,7 +1990,7 @@ def _histogramSpheric(
     cntrs = sg.cellCenters()
     counts = np.zeros(len(cntrs))
     for p in ptsvals:
-        cell = sg.closestPoint(p, returnIds=True)
+        cell = sg.closestPoint(p, returnCellId=True)
         counts[cell] += 1
     acounts = np.array(counts)
     counts *= (rmax - 1) / np.max(counts)
@@ -2125,11 +2312,8 @@ def streamplot(X, Y, U, V, direction="both",
         - 2 - vary line width vector magnitude
         - 3 - vary line width by absolute value of first vector component
 
-    |plot7_stream| |plot7_stream.py|_
+    |plot_stream| |plot_stream.py|_
     """
-    # from vedo.volume import Volume
-    # from vedo.base import streamLines
-
     n = len(X)
     m = len(Y[0])
     if n != m:
@@ -2176,10 +2360,139 @@ def streamplot(X, Y, U, V, direction="both",
     stream.lighting('off')
 
     stream.scale([1 / (n - 1) * (xmax - xmin), 1 / (n - 1) * (ymax - ymin), 1])
-    stream.addPos(np.array([xmin, ymin, 0]))
+    stream.shift(xmin, ymin)
     return stream
 
 
+def matrix(M,
+           title='Matrix',
+           xtitle='',
+           ytitle='',
+           xlabels=[],
+           ylabels=[],
+           xrotation=0,
+           cmap='Reds',
+           vmin=None,
+           vmax=None,
+           precision=2,
+           font='Theemim',
+           scale=0,
+           scalarbar=True,
+           lc='white',
+           lw=0,
+           c='black',
+           alpha=1,
+    ):
+    """
+    Generate a matrix, or a 2D color-coded plot with bin labels.
+
+    Returns an ``Assembly`` object.
+
+    Parameters
+    ----------
+    M : list or numpy array
+        the input array to visualize.
+    title : str, optional
+        title of the plot. The default is 'Matrix'.
+    xtitle : str, optional
+        title of the horizontal colmuns. The default is ''.
+    ytitle : str, optional
+        title of the vertical rows. The default is ''.
+    xlabels : list, optional
+        individual string labels for each column. Must be of length m. The default is [].
+    ylabels : list, optional
+        individual string labels for each row. Must be of length n. The default is [].
+    xrotation : float, optional
+        rotation of the horizontal labels. The default is 0.
+    cmap : str, optional
+        color map name. The default is 'Reds'.
+    vmin : float, optional
+        minimum value of the colormap range. The default is None.
+    vmax : float, optional
+        maximum value of the colormap range. The default is None.
+    precision : int, optional
+        number of digits for the matrix entries or bins. The default is 2.
+    font : str, optional
+        font name. The default is ''.
+    scale : float, optional
+        size of the numeric entries or bin values. The default is 0.
+    scalarbar : bool, optional
+        add a scalar bar to the right of the plot. The default is True.
+    lc : str, optional
+        color of the line separating the bins. The default is 'white'.
+    lw : float, optional
+        Width of the line separating the bins. The default is 0.
+    c : str, optional
+        text color. The default is 'k'.
+    alpha : float, optional
+        plot transparency. The default is 1.
+    """
+    M = np.asarray(M)
+    n,m = M.shape
+    gr = shapes.Grid(resx=m, resy=n, sx=m/(m+n)*2, sy=n/(m+n)*2, c=c, alpha=alpha)
+    gr.wireframe(False).lc(lc).lw(lw)
+
+    matr = np.flip( np.flip(M), axis=1).ravel(order='C')
+    gr.cmap(cmap, matr, on='cells', vmin=vmin, vmax=vmax)
+    sbar=None
+    if scalarbar:
+        gr.addScalarBar3D(titleFont=font, labelFont=font)
+        sbar = gr.scalarbar
+    labs=None
+    if scale !=0:
+        labs = gr.labels(cells=True, scale=scale/max(m,n),
+                         precision=precision, font=font, justify='center', c=c)
+        labs.z(0.001)
+    t = None
+    if title:
+        if title == 'Matrix':
+            title += ' '+str(n)+'x'+str(m)
+        t = shapes.Text3D(title, font=font, s=0.04,
+                          justify='bottom-center', c=c)
+        t.shift(0, n/(m+n)*1.05)
+
+    xlabs=None
+    if len(xlabels)==m:
+        xlabs=[]
+        jus = 'top-center'
+        if xrotation>44:
+            jus = 'right-center'
+        for i in range(m):
+            xl = shapes.Text3D(xlabels[i], font=font, s=0.02,
+                               justify=jus, c=c).rotateZ(xrotation)
+            xl.shift((2*i-m+1)/(m+n), -n/(m+n)*1.05)
+            xlabs.append(xl)
+
+    ylabs=None
+    if len(ylabels)==n:
+        ylabs=[]
+        for i in range(n):
+            yl = shapes.Text3D(ylabels[i], font=font, s=.02,
+                               justify='right-center', c=c)
+            yl.shift(-m/(m+n)*1.05, (2*i-n+1)/(m+n))
+            ylabs.append(yl)
+
+    xt=None
+    if xtitle:
+        xt = shapes.Text3D(xtitle, font=font, s=0.035,
+                           justify='top-center', c=c)
+        xt.shift(0, -n/(m+n)*1.05)
+        if xlabs is not None:
+            y0,y1 = xlabs[0].ybounds()
+            xt.shift(0, -(y1-y0)-0.55/(m+n))
+    yt=None
+    if ytitle:
+        yt = shapes.Text3D(ytitle, font=font, s=0.035,
+                           justify='bottom-center', c=c).rotateZ(90)
+        yt.shift(-m/(m+n)*1.05, 0)
+        if ylabs is not None:
+            x0,x1 = ylabs[0].xbounds()
+            yt.shift(-(x1-x0)-0.55/(m+n),0)
+    asse = Assembly(gr, sbar, labs, t, xt, yt, xlabs, ylabs)
+    asse.name = "Matrix"
+    return asse
+
+
 def cornerPlot(points, pos=1, s=0.2, title="", c="b", bg="k", lines=True, dots=True):
     """
     Return a ``vtkXYPlotActor`` that is a plot of `x` versus `y`,
@@ -2265,8 +2578,8 @@ def cornerHistogram(
     c="g",
     bg="k",
     alpha=1,
-    pos=1,
-    s=0.2,
+    pos="bottom-left",
+    s=0.175,
     lines=True,
     dots=False,
 ):
