@@ -19,7 +19,6 @@ __all__ = [
     "geometry",
     "isSequence",
     "linInterpolate",
-    "fitCircle2D",
     "vector",
     "mag",
     "mag2",
@@ -531,9 +530,9 @@ def linInterpolate(x, rangeX, rangeY):
         x = np.array(x)
         x0, x1 = np.array(rangeX)
         y0, y1 = np.array(rangeY)
-        if len(np.unique([x.shape, x0.shape, x1.shape, y1.shape]))>1:
-            printc("Error in linInterpolate(): mismatch in input shapes.", c='r')
-            raise RuntimeError()
+        # if len(np.unique([x.shape, x0.shape, x1.shape, y1.shape]))>1:
+        #     printc("Error in linInterpolate(): mismatch in input shapes.", c='r')
+        #     raise RuntimeError()
         dx = x1 - x0
         dxn = np.linalg.norm(dx)
         if not dxn:
@@ -542,6 +541,11 @@ def linInterpolate(x, rangeX, rangeY):
         t = np.linalg.norm(x - x1) / dxn
         st = s + t
         out = y0 * (t/st) + y1 * (s/st)
+        # allx = []
+        # for xx in x:
+        #     allx.append(linInterpolate(xx, rangeX, rangeY))
+        # out = np.array(allx)
+
     else: #faster
         x0 = rangeX[0]
         dx = rangeX[1] - x0
@@ -552,65 +556,6 @@ def linInterpolate(x, rangeX, rangeY):
     return out
 
 
-def fitCircle2D(points):
-    """
-    Fits a circle through points in the plane, with a very fast non-iterative method.
-
-    Returns the tuple (center_x, center_y, radius).
-
-    Reference: J.F. Crawford, Nucl. Instr. Meth. 211, 1983, 223-225.
-
-    .. note:: E.g.:
-
-        .. code-block:: python
-
-            from vedo import *
-
-            x = arange(0, 3, 0.1)
-            y = sin(x)
-
-            cx, cy, R = fitCircle2D([x,y])
-            Points([x, y])
-            Point([cx, cy])
-            Circle([cx, cy], r=R)
-            show(..., axes=8)
-    """
-    if len(points) == 2:
-        data = np.c_[points[0],points[1]]
-    else:
-        data = np.array(points)
-    xi = data[:,0]
-    yi = data[:,1]
-
-    x   = sum(xi)
-    xx  = sum(xi*xi)
-    xxx = sum(xi*xi*xi)
-
-    y   = sum(yi)
-    yy  = sum(yi*yi)
-    yyy = sum(yi*yi*yi)
-
-    xy  = sum(xi*yi)
-    xyy = sum(xi*yi*yi)
-    xxy = sum(xi*xi*yi)
-
-    N = len(xi)
-    k = (xx+yy)/N
-
-    a1 = xx-x*x/N
-    b1 = xy-x*y/N
-    c1 = 0.5*(xxx + xyy - x*k)
-
-    a2 = xy-x*y/N
-    b2 = yy-y*y/N
-    c2 = 0.5*(xxy + yyy - y*k)
-
-    x0 = (b1*c2 - b2*c1)/(a2*b1 - a1*b2)
-    y0 = (c1 - a1*x0)/b1
-
-    R = np.sqrt(x0*x0 + y0*y0 -1/N*(2*x0*x +2*y0*y -xx -yy))
-    return x0, y0, R
-
 
 def vector(x, y=None, z=0.0, dtype=np.float64):
     """Return a 3D numpy array representing a vector.
@@ -618,12 +563,13 @@ def vector(x, y=None, z=0.0, dtype=np.float64):
     If `y` is ``None``, assume input is in the form `[x,y,z]`.
     """
     if y is None:  # assume x is already [x,y,z]
-        return np.array(x, dtype=dtype)
+        return np.asarray(x, dtype=dtype)
     return np.array([x, y, z], dtype=dtype)
 
 
-def versor(v):
+def versor(x, y=None, z=0.0, dtype=np.float64):
     """Return the unit vector. Input can be a list of vectors."""
+    v = vector(x,y,z,dtype)
     if isinstance(v[0], np.ndarray):
         return np.divide(v, mag(v)[:, None])
     else:
@@ -665,10 +611,17 @@ def precision(x, p, vrange=None, delimiter='e'):
         out = '('
         nn=len(x)-1
         for i, ix in enumerate(x):
+
+            if np.isnan(ix):
+                return "NaN"
+
             out += precision(ix, p)
             if i<nn: out += ', '
         return out+')' ############ <--
 
+    if np.isnan(x):
+        return "NaN"
+
     x = float(x)
 
     if x == 0.0 or (vrange is not None and abs(x) < vrange/pow(10,p)):
@@ -785,17 +738,15 @@ def grep(filename, tag, firstOccurrence=False):
     except:
         print("Error in utils.grep(): cannot open file", filename)
         raise RuntimeError()
-    content = None
+
+    content = []
     for line in afile:
         if re.search(tag, line):
-            content = line.split()
+            c = line.split()
+            c[-1] = c[-1].replace('\n', '')
+            content.append(c)
             if firstOccurrence:
                 break
-    if content:
-        if len(content) == 2:
-            content = content[1]
-        else:
-            content = content[1:]
     afile.close()
     return content
 
@@ -803,7 +754,6 @@ def grep(filename, tag, firstOccurrence=False):
 def printInfo(obj):
     """Print information about a vtk object."""
 
-    from vedo.tetmesh import TetMesh
 
     def printvtkactor(actor, tab=""):
 
@@ -831,9 +781,9 @@ def printInfo(obj):
         print(tab, end="")
         printc("Mesh", c="g", bold=1, invert=1, dim=1, end=" ")
 
-        if hasattr(actor, "_legend") and actor._legend:
+        if 'legend' in actor.info.keys() and actor.info['legend']:
             printc("legend: ", c="g", bold=1, end="")
-            printc(actor._legend, c="g", bold=0)
+            printc(actor.info['legend'], c="g", bold=0)
         else:
             print()
 
@@ -982,12 +932,7 @@ def printInfo(obj):
 
     elif isinstance(obj, vtk.vtkAssembly):
         printc("_" * 65, c="g", bold=0)
-        printc("vtkAssembly", c="g", bold=1, invert=1, end=" ")
-        if hasattr(obj, "_legend"):
-            printc("legend: ", c="g", bold=1, end="")
-            printc(obj._legend, c="g", bold=0)
-        else:
-            print()
+        printc("vtkAssembly", c="g", bold=1, invert=1)
 
         pos = obj.GetPosition()
         bnds = obj.GetBounds()
@@ -1010,17 +955,12 @@ def printInfo(obj):
             if isinstance(act, vtk.vtkActor):
                 printvtkactor(act, tab="     ")
 
-    elif isinstance(obj, TetMesh):
-        return # todo
+    # elif isinstance(obj, vedo.TetMesh):
+    #     return # todo
 
     elif isinstance(obj, vtk.vtkVolume):
         printc("_" * 65, c="b", bold=0)
-        printc("vtkVolume", c="b", bold=1, invert=1, end=" ")
-        if hasattr(obj, "_legend") and obj._legend:
-            printc("legend: ", c="b", bold=1, end="")
-            printc(obj._legend, c="b", bold=0)
-        else:
-            print()
+        printc("vtkVolume", c="b", bold=1, invert=1)
 
         pos = obj.GetPosition()
         bnds = obj.GetBounds()
@@ -1088,6 +1028,8 @@ def printInfo(obj):
         if not otit:
             otit = None
         printc("   title:", otit, bold=0, c="c")
+        printc("     window size:", obj.window.GetSize(),
+               "- full screen size:", obj.window.GetScreenSize(), bold=0, c="c")
         printc(" active renderer:", obj.renderers.index(obj.renderer), bold=0, c="c")
         printc("   nr. of actors:", len(acts), bold=0, c="c", end="")
         printc(" (" + str(totpt), "vertices)", bold=0, c="c")
@@ -1383,12 +1325,17 @@ def vtkCameraToK3D(vtkcam):
     return np.array(kam).ravel()
 
 
-def make_ticks(x0, x1, N, labels=None, digits=None):
-
+def makeTicks(x0, x1, N, labels=None, digits=None):
+    # Copyright M. Musy, 2021, license: MIT.
     ticks_str, ticks_float = [], []
 
+    if x1 <= x0:
+        # printc("Error in makeTicks(): x0 >= x1", x0,x1, c='r')
+        return np.array([0.0,1.0]), ["",""]
+
     if labels is not None:
         # user is passing custom labels
+
         ticks_float.append(0)
         ticks_str.append('')
         for tp, ts in labels:
@@ -1399,55 +1346,47 @@ def make_ticks(x0, x1, N, labels=None, digits=None):
             ticks_float.append(tickn)
 
     else:
-
-        # automatic
-        dstep = (x1-x0)/N  # desired step size
-        if dstep <= 0:
-            return [0,1], ["",""]
-
-        if x0:
-            expo = np.floor(np.log10(abs(x0)))
-            lowBound = pow(10, expo)*np.sign(x0)
-        else:
-            lowBound = 0.0
-        if np.sign(x0)<0: lowBound *= 10
-        if   lowBound>0 and lowBound-dstep < 0: lowBound = 0
-        elif lowBound<0 and lowBound+dstep > 0:
-            lowBound = - pow(10, np.floor(np.log10(dstep)))
-
-        if x1:
-            expo = np.ceil(np.log10(abs(x1)))
-            upBound = pow(10, expo)*np.sign(x1)
-        else:
-            upBound = 0
-        if upBound<0 and lowBound+dstep > 0:
-            upBound = 0
-        if -1<=upBound<0:
-            upBound /= 10
-        if lowBound == upBound:
-            if upBound<0:
-                upBound /= 10
-            else:
-                upBound *= 10
+        # ..now comes one of the shortest and most painful pieces of code i ever wrote:
+        # automatically choose the best natural axis subdivision based on multiples of 1,2,5
+        dstep = (x1-x0)/N  # desired step size, begin of the nightmare
 
         basestep = pow(10, np.floor(np.log10(dstep)))
-        steps = np.asarray([basestep*i for i in (1,2,4,5,10,20,40,50)])
+        steps = np.array([basestep*i for i in (1,2,5,10,20,50)])
         idx = (np.abs(steps-dstep)).argmin()
-        s = steps[idx]
-        if not s or (upBound-lowBound)/s > 100000 or upBound == lowBound:
-            return [0,1], ["",""]
+        s = steps[idx]  # chosen step size
 
-        sel_axis = np.arange(lowBound, upBound, s)
-        sel_axis = np.clip(sel_axis, x0, x1)
-        sel_axis = np.unique(sel_axis)
+        lowBound, upBound = 0, 0
+        if x0 < 0:
+            lowBound = -pow(10, np.ceil(np.log10(-x0)))
+        if x1 > 0:
+            upBound = pow(10, np.ceil(np.log10(x1)))
+
+        if lowBound<0:
+            if upBound<0:
+                negaxis = np.arange(lowBound, int(upBound/s)*s)
+            else:
+                negaxis = np.arange(lowBound, 0, s)
+        else:
+            negaxis = np.array([])
+
+        if upBound>0:
+            if lowBound>0:
+                posaxis = np.arange(int(lowBound/s)*s, upBound, s)
+            else:
+                posaxis = np.arange(0, upBound, s)
+        else:
+            posaxis = np.array([])
+
+        fulaxis = np.unique(np.clip(np.concatenate([negaxis, posaxis]), x0, x1))
+        #end of the nightmare
 
         if digits is None:
             np.set_printoptions(suppress=True) # avoid zero precision
-            sas = str(sel_axis).replace('[','').replace(']','')
+            sas = str(fulaxis).replace('[','').replace(']','')
             sas = sas.replace('.e','e').replace('e+0','e+').replace('e-0','e-')
             np.set_printoptions(suppress=None) # set back to default
         else:
-            sas = precision(sel_axis, digits, vrange=(x0,x1))
+            sas = precision(fulaxis, digits, vrange=(x0,x1))
             sas = sas.replace('[','').replace(']','').replace(')','').replace(',','')
 
         sas2 = []
@@ -1459,22 +1398,18 @@ def make_ticks(x0, x1, N, labels=None, digits=None):
             if digits is not None and 'e' in s: s+=' ' # add space to terminate modifiers
             sas2.append(s)
 
-        for i in range(len(sel_axis)):
+        for i in range(len(fulaxis)):
             ts = sas2[i]
-            tp = sel_axis[i]
+            tp = fulaxis[i]
             if tp == x1:
                 continue
             tickn = linInterpolate(tp, [x0,x1], [0,1])
             ticks_float.append(tickn)
             ticks_str.append(ts)
-        #printc('------------------------------------------------', c='y')
-        #printc('x0, x1, N       = ', x0, x1, N, c='y')
-        #printc('bounds            ', lowBound, upBound)
-        #printc('dstep, steps      ', dstep, steps)
-        #printc('Result tick array\n', sel_axis, sel_axis.shape[0], c='y')
 
     ticks_str.append('')
     ticks_float.append(1)
+    ticks_float = np.array(ticks_float)
     return ticks_float, ticks_str
 
 
@@ -1570,7 +1505,6 @@ def trimesh2vedo(inputobj, alphaPerCell=False):
         return tact
 
     elif "PointCloud" in inputobj_type:
-        from vedo.shapes import Points
 
         trim_cc, trim_al = "black", 1
         if hasattr(inputobj, "vertices_color"):
@@ -1579,22 +1513,55 @@ def trimesh2vedo(inputobj, alphaPerCell=False):
                 trim_cc = trim_c[:, [0, 1, 2]] / 255
                 trim_al = trim_c[:, 3] / 255
                 trim_al = np.sum(trim_al) / len(trim_al)  # just the average
-        return Points(inputobj.vertices, r=8, c=trim_cc, alpha=trim_al)
+        return vedo.shapes.Points(inputobj.vertices, r=8, c=trim_cc, alpha=trim_al)
 
     elif "path" in inputobj_type:
-        from vedo.shapes import Line
-        from vedo.assembly import Assembly
 
         lines = []
         for e in inputobj.entities:
             # print('trimesh entity', e.to_dict())
-            l = Line(inputobj.vertices[e.points], c="k", lw=2)
+            l = vedo.shapes.Line(inputobj.vertices[e.points], c="k", lw=2)
             lines.append(l)
-        return Assembly(lines)
+        return vedo.Assembly(lines)
 
     return None
 
 
+def vedo2meshlab(vmesh):
+    try:
+        import pymeshlab as mlab
+    except RuntimeError:
+        printc("Need pymeshlab to run: pip install pymeshlab", c='r')
+
+    ms = mlab.MeshSet()
+    m = mlab.Mesh(vertex_matrix=vmesh.points(),
+                  face_matrix=vmesh.faces(),
+                  v_normals_matrix=vmesh.normals(cells=False, compute=False),
+                  f_normals_matrix=vmesh.normals(cells=True, compute=False),
+                 )
+    m.update_bounding_box()
+    ms.add_mesh(m)
+    return ms
+
+def meshlab2vedo(mmesh):
+    inputtype = str(type(mmesh))
+
+    if "MeshSet" in inputtype:
+        mmesh = mmesh.current_mesh()
+    mpoints, mcells = mmesh.vertex_matrix(), mmesh.face_matrix()
+    pnorms = mmesh.vertex_normal_matrix()
+    cnorms = mmesh.face_normal_matrix()
+    if len(mcells):
+        polydata = buildPolyData(mpoints, mcells)
+    else:
+        polydata = buildPolyData(mpoints, None)
+    if len(pnorms):
+        polydata.GetPointData().SetNormals(numpy_to_vtk(pnorms, deep=True))
+    if len(cnorms):
+        polydata.GetCellData().SetNormals(numpy_to_vtk(cnorms, deep=True))
+    return polydata
+
+
 def vtkVersionIsAtLeast(major, minor=0, build=0):
     """
     Check the VTK version.
@@ -1618,29 +1585,29 @@ def vtkVersionIsAtLeast(major, minor=0, build=0):
     else:
         return False
 
-def systemReport():
-    try:
-        import scooby
-        r = scooby.Report(additional=['vtk',
-                                      'vedo',
-                                      'meshio',
-                                      'matplotlib',
-                                      'k3d',
-                                      'itkwidgets',
-                                      'panel',
-                                      'dolfin',
-                                      'trimesh',
-                                      'pymeshfix',
-                                      'pygmsh',
-                                      'nevergrad',
-                                      'pyshtools',
-                                      'cv2',
-                                      ])
-        printc(r)
-    except:
-        print('Install scooby with command: pip install scooby')
-        r = ''
-    return r
+# def systemReport():
+#     try:
+#         import scooby
+#         r = scooby.Report(additional=['vtk',
+#                                       'vedo',
+#                                       'meshio',
+#                                       'matplotlib',
+#                                       'k3d',
+#                                       'itkwidgets',
+#                                       'panel',
+#                                       'dolfin',
+#                                       'trimesh',
+#                                       'pymeshfix',
+#                                       'pygmsh',
+#                                       'nevergrad',
+#                                       'pyshtools',
+#                                       'cv2',
+#                                       ])
+#         printc(r)
+#     except:
+#         print('Install scooby with command: pip install scooby')
+#         r = ''
+#     return r
 
 
 def ctf2lut(tvobj):
