@@ -245,29 +245,58 @@ class Volume(vtk.vtkVolume, BaseGrid):
 
     :param int mode: define the volumetric rendering style:
 
-        - 0, Composite rendering
+        - 0, composite rendering
         - 1, maximum projection rendering
         - 2, minimum projection
         - 3, average projection
         - 4, additive mode
 
+        The default mode is "composite" where the scalar values are sampled through
+        the volume and composited in a front-to-back scheme through alpha blending.
+        The final color and opacity is determined using the color and opacity transfer
+        functions specified in alpha keyword.
+
+        Maximum and minimum intensity blend modes use the maximum and minimum
+        scalar values, respectively, along the sampling ray.
+        The final color and opacity is determined by passing the resultant value
+        through the color and opacity transfer functions.
+
+        Additive blend mode accumulates scalar values by passing each value
+        through the opacity transfer function and then adding up the product
+        of the value and its opacity. In other words, the scalar values are scaled
+        using the opacity transfer function and summed to derive the final color.
+        Note that the resulting image is always grayscale i.e. aggregated values
+        are not passed through the color transfer function.
+        This is because the final value is a derived value and not a real data value
+        along the sampling ray.
+
+        Average intensity blend mode works similar to the additive blend mode where
+        the scalar values are multiplied by opacity calculated from the opacity
+        transfer function and then added.
+        The additional step here is to divide the sum by the number of samples
+        taken through the volume.
+        As is the case with the additive intensity projection, the final image will
+        always be grayscale i.e. the aggregated values are not passed through the
+        color transfer function.
+
     .. hint:: if a `list` of values is used for `alphas` this is interpreted
         as a transfer function along the range of the scalar.
 
-        |read_vti| |read_vti.py|_
+        |read_volume2| |read_volume2.py|_
     """
 
     def __init__(self, inputobj=None,
-                 c=('r','y','lg','lb','b'), #('b','lb','lg','y','r')
-                 alpha=(0.0, 0.0, 0.5, 0.8, 1.0),
+                 c='RdBu_r',
+                 alpha=(0.0, 0.0, 0.2, 0.4, 0.8, 1.0),
                  alphaGradient=None,
                  alphaUnit=1,
                  mode=0,
+                 shade=False,
                  spacing=None,
                  dims=None,
                  origin=None,
                  mapper='smart',
-                 ):
+        ):
 
         vtk.vtkVolume.__init__(self)
         BaseGrid.__init__(self)
@@ -283,6 +312,22 @@ class Volume(vtk.vtkVolume, BaseGrid):
             else:
                 inputobj = sorted(glob.glob(inputobj))
 
+        ###################
+        if 'gpu' in mapper:
+            self._mapper = vtk.vtkGPUVolumeRayCastMapper()
+        elif 'opengl_gpu' in mapper:
+            self._mapper = vtk.vtkOpenGLGPUVolumeRayCastMapper()
+        elif 'smart' in mapper:
+            self._mapper = vtk.vtkSmartVolumeMapper()
+        elif 'fixed' in mapper:
+            self._mapper = vtk.vtkFixedPointVolumeRayCastMapper()
+        elif isinstance(mapper, vtk.vtkMapper):
+            self._mapper = mapper
+        else:
+            print("Error unknown mapper type", [mapper])
+            raise RuntimeError()
+        self.SetMapper(self._mapper)
+
         ###################
         inputtype = str(type(inputobj))
         #colors.printc('Volume inputtype', inputtype)
@@ -344,6 +389,9 @@ class Volume(vtk.vtkVolume, BaseGrid):
         elif "ImageData" in inputtype:
             img = inputobj
 
+        elif isinstance(inputobj, Volume):
+            img = inputobj.inputdata()
+
         elif "UniformGrid" in inputtype:
             img = inputobj
 
@@ -362,20 +410,6 @@ class Volume(vtk.vtkVolume, BaseGrid):
             colors.printc("Volume(): cannot understand input type:\n", inputtype, c='r')
             return
 
-        ###################
-        if 'gpu' in mapper:
-            self._mapper = vtk.vtkGPUVolumeRayCastMapper()
-        elif 'opengl_gpu' in mapper:
-            self._mapper = vtk.vtkOpenGLGPUVolumeRayCastMapper()
-        elif 'smart' in mapper:
-            self._mapper = vtk.vtkSmartVolumeMapper()
-        elif 'fixed' in mapper:
-            self._mapper = vtk.vtkFixedPointVolumeRayCastMapper()
-        elif isinstance(mapper, vtk.vtkMapper):
-            self._mapper = mapper
-        else:
-            print("Error unknown mapper type", [mapper])
-            raise RuntimeError()
 
         if dims is not None:
             img.SetDimensions(dims)
@@ -388,8 +422,8 @@ class Volume(vtk.vtkVolume, BaseGrid):
 
         self._data = img
         self._mapper.SetInputData(img)
-        self.SetMapper(self._mapper)
         self.mode(mode).color(c).alpha(alpha).alphaGradient(alphaGradient)
+        self.GetProperty().SetShade(True)
         self.GetProperty().SetInterpolationType(1)
         self.GetProperty().SetScalarOpacityUnitDistance(alphaUnit)
 
@@ -402,8 +436,10 @@ class Volume(vtk.vtkVolume, BaseGrid):
 
     def _update(self, img):
         self._data = img
+        self._data.GetPointData().Modified()
         self._mapper.SetInputData(img)
         self._mapper.Modified()
+        self._mapper.Update()
         return self
 
     def mode(self, mode=None):
@@ -414,6 +450,34 @@ class Volume(vtk.vtkVolume, BaseGrid):
             - 2, minimum projection rendering
             - 3, average projection rendering
             - 4, additive mode
+
+        The default mode is "composite" where the scalar values are sampled through
+        the volume and composited in a front-to-back scheme through alpha blending.
+        The final color and opacity is determined using the color and opacity transfer
+        functions specified in alpha keyword.
+
+        Maximum and minimum intensity blend modes use the maximum and minimum
+        scalar values, respectively, along the sampling ray.
+        The final color and opacity is determined by passing the resultant value
+        through the color and opacity transfer functions.
+
+        Additive blend mode accumulates scalar values by passing each value
+        through the opacity transfer function and then adding up the product
+        of the value and its opacity. In other words, the scalar values are scaled
+        using the opacity transfer function and summed to derive the final color.
+        Note that the resulting image is always grayscale i.e. aggregated values
+        are not passed through the color transfer function.
+        This is because the final value is a derived value and not a real data value
+        along the sampling ray.
+
+        Average intensity blend mode works similar to the additive blend mode where
+        the scalar values are multiplied by opacity calculated from the opacity
+        transfer function and then added.
+        The additional step here is to divide the sum by the number of samples
+        taken through the volume.
+        As is the case with the additive intensity projection, the final image will
+        always be grayscale i.e. the aggregated values are not passed through the
+        color transfer function.
         """
         if mode is None:
             return self._mapper.GetBlendMode()
@@ -437,22 +501,38 @@ class Volume(vtk.vtkVolume, BaseGrid):
                 colors.printc("Error in volume.mode(): unknown mode", mode, c='r')
                 mode = 0
 
-        volumeProperty = self.GetProperty()
         self._mapper.SetBlendMode(mode)
         self._mode = mode
-        if mode == 0:
-            volumeProperty.ShadeOn()
-            self.lighting('shiny')
-            self.jittering(True)
-        elif mode == 1:
-            volumeProperty.ShadeOff()
-            self.jittering(True)
+        return self
+
+    def shade(self, status=None):
+        """
+        Set/Get the shading of a Volume.
+        Shading can be further controlled with ``volume.lighting()`` method.
+
+        If shading is turned on, the mapper may perform shading calculations.
+        In some cases shading does not apply
+        (for example, in maximum intensity projection mode).
+        """
+        if status is None:
+            return self.GetProperty().GetShade()
+        self.GetProperty().SetShade(status)
         return self
 
     def cmap(self, c):
         """Same as color() or c()."""
         return self.c(c)
 
+    def jittering(self, status=None):
+        """If `jittering` is `True`, each ray traversal direction will be perturbed slightly
+        using a noise-texture to get rid of wood-grain effects.
+        """
+        if hasattr(self._mapper, 'SetUseJittering'): # tetmesh doesnt have it
+            if status is None:
+                return self._mapper.GetUseJittering()
+            self._mapper.SetUseJittering(status)
+        return self
+
     def clone(self):
         """Return a clone copy of the Volume."""
         newimg = vtk.vtkImageData()
@@ -468,16 +548,6 @@ class Volume(vtk.vtkVolume, BaseGrid):
         newvol.SetPosition(self.GetPosition())
         return newvol
 
-    def jittering(self, status=None):
-        """If `jittering` is `True`, each ray traversal direction will be perturbed slightly
-        using a noise-texture to get rid of wood-grain effects.
-        """
-        if hasattr(self._mapper, 'SetUseJittering'):
-            if status is None:
-                return self._mapper.GetUseJittering()
-            self._mapper.SetUseJittering(status)
-        return self
-
     def imagedata(self):
         """Return the underlying vtkImagaData object."""
         return self._data
@@ -579,7 +649,7 @@ class Volume(vtk.vtkVolume, BaseGrid):
 
         The format for alphaGrad is the same as for method ``volume.alpha()``.
 
-        |read_vti| |read_vti.py|_
+        |read_volume2| |read_volume2.py|_
         """
         self._alphaGrad = alphaGrad
         volumeProperty = self.GetProperty()
@@ -628,7 +698,8 @@ class Volume(vtk.vtkVolume, BaseGrid):
         self.GetProperty().SetComponentWeight(i, weight)
         return self
 
-    def threshold(self, above=None, below=None, replaceWith=0):
+
+    def threshold(self, above=None, below=None, replace=None, replaceOut=None):
         """
         Binary or continuous volume thresholding.
         Find the voxels that contain a value above/below the input values
@@ -637,27 +708,41 @@ class Volume(vtk.vtkVolume, BaseGrid):
         th = vtk.vtkImageThreshold()
         th.SetInputData(self.imagedata())
 
+        # sanity checks
         if above is not None and below is not None:
-            if above<below:
-                th.ThresholdBetween(above, below)
-                th.SetInValue(replaceWith)
-            elif above==below:
+            if above==below:
                 return self
-            else:
-                th.SetReplaceOut(True)
-                th.SetOutValue(replaceWith)
-                th.ThresholdBetween(below, above)
+            if above > below:
+                colors.printc("Warning in volume.threshold(): above > below, skip.", c='y')
+                return self
+
+        ## cases
+        if below is not None and above is not None:
+            th.ThresholdBetween(above, below)
 
         elif above is not None:
             th.ThresholdByUpper(above)
-            th.SetInValue(replaceWith)
 
         elif below is not None:
             th.ThresholdByLower(below)
-            th.SetInValue(replaceWith)
+
+        ##
+        if replace is not None:
+            th.SetReplaceIn(True)
+            th.SetInValue(replace)
+        else:
+            th.SetReplaceIn(False)
+
+        if replaceOut is not None:
+            th.SetReplaceOut(True)
+            th.SetOutValue(replaceOut)
+        else:
+            th.SetReplaceOut(False)
 
         th.Update()
-        return self._update(th.GetOutput())
+        out = th.GetOutput()
+        return self._update(out)
+
 
     def crop(self,
              left=None, right=None,
